<?php

namespace App\Contracts;

use App\Exceptions\FailedResponseException;
use App\Facades\OTP;
use App\Helper\FailedResponseCode;
use App\Services\Auth\OTPService;
use Illuminate\Support\Carbon;
use Illuminate\Support\Str;

abstract class AProfile
{
    protected $data;
    protected $user;

    public function setData($data): static
    {
        $this->data = is_object($data) ? $data : (object)$data;
        return $this;
    }

    public function setUser($user): static
    {
        $this->user = $user;
        return $this;
    }

    public function verify($data)
    {
        $userType = Str::lower($this->user->role);

        if (!OTP::verify("profile_{$userType}_{$data}", $this->data->otp)) {
            throw new FailedResponseException(trans('failed-messages.otp_invalid'), FailedResponseCode::OTP_INVALID);
        }
        return $this;
    }

    public function sendOtp($data)
    {
        $userType = Str::lower($this->user->role);

        return successResponse([
            'code' => OTPService::sendCode($data, "profile_{$userType}_$data->email"),
            'status' => 'OTP'
        ]);
    }

    public function updateEmail()
    {
        return $this->user->update([
            'email' => $this->data->email,
            'email_verified_at' => now()
        ]);
    }

    public abstract function updateInfo();

    public function updateMobile()
    {
        return $this->user->update([
            'country_code' => $this->data->country_code,
            'mobile' => $this->data->mobile,
            'mobile_verified_at' => now()
        ]);
    }
}
