<?php

namespace App\Contracts;

use Illuminate\Support\Facades\Cache;

abstract class OTPGenerator
{
    protected $key = 'otp_';
    protected $ttl = 120;

    abstract public function generate(): mixed;

    public function save($key, $code, $ttl = null): bool
    {
        if ($this->exists($key)) {
            $this->forget($key);
        }
        return Cache::add("{$this->key}$key", $code, $ttl ?? $this->ttl);
    }

    public function exists($key): bool
    {
        return Cache::has("{$this->key}$key");
    }

    public function verify($key, $code): bool
    {
        if (!$this->exists($key)) {
            return false;
        }
        $cacheCode = Cache::get("{$this->key}$key");

        return !is_null($cacheCode) && $cacheCode == $code;
    }

    public function get($key): mixed
    {
        return Cache::get("{$this->key}$key");
    }

    public function forget($key): bool
    {
        return Cache::forget("{$this->key}$key");
    }
}
