<?php

namespace App\Contracts;

use App\Exceptions\FailedResponseException;
use App\Facades\OTP;
use App\Helper\Enum;
use App\Helper\FailedResponseCode;
use App\Helper\Image;
use App\Helper\ReferralGenerator;
use App\Models\Marketer;
use App\Models\User;
use Illuminate\Notifications\Notifiable;
use Illuminate\Support\Str;

abstract class UsernameRegister
{
    protected $data;
    protected $referralOwner;
    protected $userType;

    public function __construct()
    {
        $this->userType = Enum::MARKETER;
    }

    public function setUserType($userType)
    {
        $this->userType = $userType;
        return $this;
    }

    public function verifyRegistration($data)
    {

        $this->data = is_object($data) ? $data : (object)$data;

        $client = User::query()->where('mobile', $this->data->mobile)->where('country_code', $this->data->country_code)->where('role', $this->userType)->first();
        if ($client)
            throw  new FailedResponseException(trans('failed-messages.user_mobile_already_exist'), FailedResponseCode::USER_MOBILE_EXIST);

        $userType = Str::lower($this->userType);

        if ($this->data->referral ?? null) {
            $this->referralOwner = ReferralGenerator::getOwner($this->data->referral);

            if (!ReferralGenerator::canInvite($this->referralOwner, $userType)) {
                throw new FailedResponseException(trans('failed-messages.invalid_referral'), FailedResponseCode::CANT_INVITE);
            }
        }


        if (!OTP::verify("{$userType}_{$this->data->email}", $this->data->otp))
            throw new FailedResponseException(trans('failed-messages.otp_invalid'), FailedResponseCode::OTP_INVALID);

        OTP::forget("{$userType}_{$this->data->email}");

        return $this;
    }

    abstract public function register(): array;

    abstract protected function sendNotification($notifiable, string $username, string $password);
}
