<?php

namespace App\Filters;

use App\Contracts\Filter;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Support\Str;

class SortBy extends Filter
{
    public function applyFilter($builder): Builder
    {
        return match (Str::upper(request('sort_by', ''))) {
            'PURCHASES' => $this->sortByPurchases($builder),
            'POPULARS' => $this->sortByFavorites($builder),
            'LATEST' => $builder->latest('id'),
            'OLDEST' => $builder->oldest('id'),
            default => $builder,
        };
    }

    private function sortByPurchases($builder)
    {
        $builder->withCount(['orders' => fn($orderQuery) => $orderQuery->paid()]);

        return $builder->orderBy('orders_count', 'desc');
    }

    private function sortByFavorites($builder)
    {
        $builder->withCount(['bookmarks']);
        return $builder->orderBy('bookmarks_count', 'desc');
    }
}
