<?php

namespace App\Helper;

use App\Exceptions\FailedResponseException;
use App\Models\User;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasManyThrough;
use Illuminate\Support\Str;

class ReferralGenerator
{
    public static function generate($model = User::class, $field = 'referral_code', $length = 8, \Closure $callback = null): string
    {
        do {
            $code = isset($callback) ? $callback() : Str::random($length);
        } while (!!$model::query()->where($field, $code)->first());

        return $code;
    }

    public static function saveInvite(User $inviter, User $invited): Model|HasManyThrough
    {
        if (!static::canInvite($inviter, $invited)) {
            throw new FailedResponseException(trans('failed-messages.invalid_referral'), FailedResponseCode::CANT_INVITE);
        }

        return $inviter->invites()->create([
            'invited_id' => $invited->id,
        ]);
    }

    public static function unlinkInvite(User $inviter, User $invited)
    {
        return $inviter->invites()->where([
            'invited_id' => $invited->id,
        ])->delete();
    }

    public static function getOwner($code)
    {
        $user = User::where('referral_code', $code)->first();

        if (!$user)
            throw new FailedResponseException(trans('failed-messages.invalid_referral'), FailedResponseCode::INVALID_REFERRAL);

        return $user;
    }

    public static function canInvite(User $inviter, User|string $invited): bool
    {
        $inviterRole = Str::lower($inviter->role);
        $invitedRole = $invited instanceof User ? Str::lower($invited->role) : $invited;

        return in_array($invitedRole, config("invites.allows.$inviterRole"));
    }
}
