<?php

use Carbon\Carbon;
use Hekmatinasser\Verta\Verta;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Response;
use Illuminate\Support\Str;
use Jenssegers\Agent\Agent;

if (!function_exists('successResponse')) {
    function successResponse($data, $message = null): JsonResponse
    {
        if (!$message) {
            $message = trans('success-messages.success_operation');
        }

        return response()->json([
            'success' => true,
            'data' => $data,
            'message' => $message
        ]);
    }
}

if (!function_exists('failedResponse')) {
    function failedResponse($message, $code, $data = null, $status = Response::HTTP_OK): JsonResponse
    {
        $responseData = ['success' => false];
        if ($data)
            $responseData['data'] = $data;

        $responseData['message'] = $message;
        $responseData['code'] = $code;

        return response()->json($responseData, $status);
    }
}

if (!function_exists('combineApplicationAgent')) {
    function combineApplicationAgent($rules): array
    {
        $agent = new Agent();
        if (!$agent->isRobot() || !Str::contains(Str::lower($agent->robot()), 'okhttp'))
            return $rules;

        $rules['device_type'] = ['required', 'string'];
        $rules['device_platform'] = ['required', 'string'];
        $rules['device_title'] = ['required', 'string'];

        return $rules;
    }
}

if (!function_exists('convertSecondToDHMS')) {
    function convertSecondToDHMS($seconds): string
    {
        $day = floor($seconds / (3600 * 24));
        $hour = floor($seconds % (3600 * 24) / 3600);
        $minute = floor($seconds % 3600 / 60);
        $second = floor($seconds % 60);

        if (!$day && !$hour && !$minute) {
            return trans('translates.s', [
                'second' => $second
            ]);
        } elseif (!$day && !$hour) {
            return trans('translates.ms', [
                'minute' => $minute,
                'second' => $second
            ]);
        } elseif (!$day) {
            return trans('translates.ms', [
                'hour' => $hour,
                'minute' => $minute,
                'second' => $second
            ]);
        }

        return trans('translates.dhms', [
            'day' => $day,
            'hour' => $hour,
            'minute' => $minute,
            'second' => $second
        ]);
    }
}

if (!function_exists('jalaliToGeorgian')) {
    function jalaliToGeorgian(string $jDate, string $format = "Y/m/d"): Carbon
    {
        return Verta::parseFormat($format, $jDate)->toCarbon();
    }
}
