<?php

namespace App\Http\Controllers\Admin;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Resources\Admin\BookRequestResource;
use App\Http\Resources\PaginateCollection;
use App\Models\BookRequest;
use App\Notifications\BookRequestDoneNotification;
use Illuminate\Http\Request;

class BookRequestController extends Controller
{
    public function __construct()
    {
        $this->middleware('can:BOOK-REQUESTS_LIST')->only(['index', 'markAsDone']);
        $this->middleware('can:BOOK-REQUESTS_DELETE')->only(['destroy']);
    }

    public function index()
    {
        $requests = BookRequest::with('user')->latest()->paginate(\request('per_page') ?? 15);

        return successResponse(new PaginateCollection($requests, BookRequestResource::class));
    }

    public function markAsDone(Request $request, BookRequest $bookRequest)
    {
        $bookRequest->load('user');
        $bookRequest->update([
            'status' => BookRequest::DONE
        ]);

        if ($bookRequest->user?->email) {
            $bookRequest->user->notify(new BookRequestDoneNotification($bookRequest));
        }

        // Todo: Send SMS if email not exists

        return successResponse(null);
    }

    public function destroy(BookRequest $bookRequest)
    {
        return $bookRequest->delete()
            ? successResponse(null)
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::FAILED_OPERATION);
    }
}
