<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\ClientWalletRequest;
use App\Http\Resources\Admin\ClientWalletResource;
use App\Models\User;
use Illuminate\Http\Request;

class ClientWalletController extends Controller
{
    public function __construct()
    {
        $this->middleware('can:WALLETS_SHOW')->only(['show']);
        $this->middleware('can:WALLETS_UPDATE')->only(['update']);
    }

    public function show(User $user)
    {
        $user->load('wallets');

        $wallets = [];
        foreach ($user->wallets as $wallet) {
            $wallets[$wallet->currency_code] = [
                'price' => $wallet->amount
            ];
        }

        return successResponse($wallets);
    }

    public function update(ClientWalletRequest $request, User $user)
    {
        $user->load('wallets');

        foreach (\request('wallets', []) as $currency => $value) {
            $user->wallets->where('currency_code', $currency)->first()?->update([
                'amount' => $value['price']
            ]);
        }

        return successResponse(null);
    }
}
