<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Admin;
use App\Models\Order;
use App\Models\OrderProduct;
use App\Models\Product;
use App\Models\ReadingReport;
use App\Models\User;
use App\Services\Admin\ReportService;
use Illuminate\Http\Request;

class DashboardController extends Controller
{
    public function index()
    {
        return successResponse('');
    }

    public function clientStats()
    {
        return successResponse([
            'users' => User::query()->whereUser()->count(),
            'marketers' => User::query()->whereMarketer()->count(),
            'publishers' => User::query()->wherePublisher()->count(),
            'admins' => Admin::query()->count()
        ]);
    }

    public function saleStats()
    {
        return successResponse([
            'total' => [
                'IRR' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'IRR')->paid())->sum('total_price'),
                'USD' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'USD')->paid())->sum('total_price'),
                'IQD' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'IQD')->paid())->sum('total_price'),
            ],
            'site' => [
                'IRR' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'IRR')->paid())->sum('total_price_site_profit'),
                'USD' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'USD')->paid())->sum('total_price_site_profit'),
                'IQD' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'IQD')->paid())->sum('total_price_site_profit'),
            ],
            'publisher' => [
                'IRR' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'IRR')->paid())->sum('total_price_publisher_profit'),
                'USD' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'USD')->paid())->sum('total_price_publisher_profit'),
                'IQD' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'IQD')->paid())->sum('total_price_publisher_profit'),
            ],
            'marketer' => [
                'IRR' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'IRR')->paid())->sum('total_price_marketer_profit'),
                'USD' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'USD')->paid())->sum('total_price_marketer_profit'),
                'IQD' => OrderProduct::query()->whereHas('order', fn($orderQuery) => $orderQuery->where('currency_code', 'IQD')->paid())->sum('total_price_marketer_profit'),
            ]
        ]);
    }

    public function saleReports(ReportService $reportService)
    {
        $electronicBooksSale = [
            'today' => $reportService->getSaleReportOf(Product::ELECTRONIC_BOOK, now()->startOfDay(), now()->endOfDay()),
            'week' => $reportService->getSaleReportOf(Product::ELECTRONIC_BOOK, now()->startOfWeek(), now()->endOfWeek()),
            'month' => $reportService->getSaleReportOf(Product::ELECTRONIC_BOOK, now()->startOfMonth(), now()->endOfMonth()),
            'year' => $reportService->getSaleReportOf(Product::ELECTRONIC_BOOK, now()->startOfYear(), now()->endOfYear())
        ];

        $audioBooksSale = [
            'today' => $reportService->getSaleReportOf(Product::AUDIO_BOOK, now()->startOfDay(), now()->endOfDay()),
            'week' => $reportService->getSaleReportOf(Product::AUDIO_BOOK, now()->startOfWeek(), now()->endOfWeek()),
            'month' => $reportService->getSaleReportOf(Product::AUDIO_BOOK, now()->startOfMonth(), now()->endOfMonth()),
            'year' => $reportService->getSaleReportOf(Product::AUDIO_BOOK, now()->startOfYear(), now()->endOfYear())
        ];

        $magazinesSale = [
            'today' => $reportService->getSaleReportOf(Product::MAGAZINE, now()->startOfDay(), now()->endOfDay()),
            'week' => $reportService->getSaleReportOf(Product::MAGAZINE, now()->startOfWeek(), now()->endOfWeek()),
            'month' => $reportService->getSaleReportOf(Product::MAGAZINE, now()->startOfMonth(), now()->endOfMonth()),
            'year' => $reportService->getSaleReportOf(Product::MAGAZINE, now()->startOfYear(), now()->endOfYear())
        ];

        $podcastsSale = [
            'today' => $reportService->getSaleReportOf(Product::PODCAST, now()->startOfDay(), now()->endOfDay()),
            'week' => $reportService->getSaleReportOf(Product::PODCAST, now()->startOfWeek(), now()->endOfWeek()),
            'month' => $reportService->getSaleReportOf(Product::PODCAST, now()->startOfMonth(), now()->endOfMonth()),
            'year' => $reportService->getSaleReportOf(Product::PODCAST, now()->startOfYear(), now()->endOfYear())
        ];

        return successResponse([
            'electronic_book' => $electronicBooksSale,
            'audio_book' => $audioBooksSale,
            'magazine' => $magazinesSale,
            'podcast' => $podcastsSale,
        ]);
    }

    public function readingReports(ReportService $reportService)
    {
        $electronicBooksReadingReports = [
            'today' => convertSecondToDHMS($reportService->getReadingReportOf(Product::ELECTRONIC_BOOK, now()->startOfDay()->toDateString(), now()->endOfDay()->toDateString())),
            'week' => convertSecondToDHMS($reportService->getReadingReportOf(Product::ELECTRONIC_BOOK, now()->startOfWeek()->toDateString(), now()->endOfWeek()->toDateString())),
            'month' => convertSecondToDHMS($reportService->getReadingReportOf(Product::ELECTRONIC_BOOK, now()->startOfMonth()->toDateString(), now()->endOfMonth()->toDateString())),
            'year' => convertSecondToDHMS($reportService->getReadingReportOf(Product::ELECTRONIC_BOOK, now()->startOfYear()->toDateString(), now()->endOfYear()->toDateString())),
        ];

        $audioBooksReadingReports = [
            'today' => convertSecondToDHMS($reportService->getReadingReportOf(Product::AUDIO_BOOK, now()->startOfDay()->toDateString(), now()->endOfDay()->toDateString())),
            'week' => convertSecondToDHMS($reportService->getReadingReportOf(Product::AUDIO_BOOK, now()->startOfWeek()->toDateString(), now()->endOfWeek()->toDateString())),
            'month' => convertSecondToDHMS($reportService->getReadingReportOf(Product::AUDIO_BOOK, now()->startOfMonth()->toDateString(), now()->endOfMonth()->toDateString())),
            'year' => convertSecondToDHMS($reportService->getReadingReportOf(Product::AUDIO_BOOK, now()->startOfYear()->toDateString(), now()->endOfYear()->toDateString())),
        ];

        $magazinesReadingReports = [
            'today' => convertSecondToDHMS($reportService->getReadingReportOf(Product::MAGAZINE, now()->startOfDay()->toDateString(), now()->endOfDay()->toDateString())),
            'week' => convertSecondToDHMS($reportService->getReadingReportOf(Product::MAGAZINE, now()->startOfWeek()->toDateString(), now()->endOfWeek()->toDateString())),
            'month' => convertSecondToDHMS($reportService->getReadingReportOf(Product::MAGAZINE, now()->startOfMonth()->toDateString(), now()->endOfMonth()->toDateString())),
            'year' => convertSecondToDHMS($reportService->getReadingReportOf(Product::MAGAZINE, now()->startOfYear()->toDateString(), now()->endOfYear()->toDateString())),
        ];

        $podcastsReadingReports = [
            'today' => convertSecondToDHMS($reportService->getReadingReportOf(Product::PODCAST, now()->startOfDay()->toDateString(), now()->endOfDay()->toDateString())),
            'week' => convertSecondToDHMS($reportService->getReadingReportOf(Product::PODCAST, now()->startOfWeek()->toDateString(), now()->endOfWeek()->toDateString())),
            'month' => convertSecondToDHMS($reportService->getReadingReportOf(Product::PODCAST, now()->startOfMonth()->toDateString(), now()->endOfMonth()->toDateString())),
            'year' => convertSecondToDHMS($reportService->getReadingReportOf(Product::PODCAST, now()->startOfYear()->toDateString(), now()->endOfYear()->toDateString())),
        ];

        return successResponse([
            'electronic_book' => $electronicBooksReadingReports,
            'audio_book' => $audioBooksReadingReports,
            'magazine' => $magazinesReadingReports,
            'podcast' => $podcastsReadingReports,
        ]);
    }
}
