<?php

namespace App\Http\Controllers\Admin;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\LoginRequest;
use App\Http\Resources\Admin\AdminResource;
use App\Http\Resources\User\UserResource;
use App\Models\Admin;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class LoginController extends Controller
{
    public function login(LoginRequest $request): JsonResponse
    {
        $data = $request->validated();
        $admin = Admin::query()->with(['role.permissions'])
            ->withCount('unreadNotifications')
            ->whereEmail($data['email'])->first();

        if (!Hash::check($data['password'], $admin->password)) {
            return failedResponse(trans('failed-messages.invalid_credentials'), FailedResponseCode::INVALID_CREDENTIALS);
        }

        return successResponse([
            'admin' => new AdminResource($admin),
            'token' => $admin->createToken('admin auth token', ['admin-access'])->accessToken
        ]);
    }
}
