<?php

namespace App\Http\Controllers\Admin;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Resources\Admin\NotificationResource;
use App\Http\Resources\PaginateCollection;
use App\Notifications\Admin\NewUserRegisteredNotification;
use Illuminate\Http\Request;

class NotificationController extends Controller
{
    public function __construct()
    {
        $this->middleware('can:NOTIFICATIONS_LIST')->only(['index']);
    }

    public function index()
    {
        $admin = auth('admin')->user();
//        $admin->notify(new NewUserRegisteredNotification());
        $notifications = $admin->notifications()->latest()->paginate(\request('per_page') ?? 15);

        return successResponse(new PaginateCollection($notifications, NotificationResource::class));
    }

    public function destroy($notification = null)
    {
        if (!$notification) {
            auth('admin')->user()->notifications()->delete();
            return successResponse(null);
        }

        return auth('admin')->user()->notifications()->findOrFail($notification)?->delete()
            ? successResponse(null)
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::FAILED_OPERATION);

    }
}
