<?php

namespace App\Http\Controllers\Admin;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Models\ProductPrice;
use Illuminate\Http\Request;

class ProductPriceController extends Controller
{
    public function __construct()
    {
        $this->middleware('can:PRODUCTS_UPDATE')->only(['removeDiscount', 'updateDiscount']);
    }

    public function updateDiscount(Request $request, ProductPrice $productPrice)
    {
        $data = $request->validate([
            'discount' => ['required', 'integer', 'min:0', 'max:90'],
            'started_at' => ['required', 'date'],
            'ended_at' => ['required', 'date'],
        ]);

        $result = $productPrice->update([
            'discount_percent' => $data['discount'],
            'discount_started_at' => $data['started_at'],
            'discount_ended_at' => $data['ended_at'],
        ]);

        return $result
            ? successResponse(null)
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::FAILED_OPERATION);
    }

    public function removeDiscount(ProductPrice $productPrice)
    {
        $result = $productPrice->update([
            'discount_percent' => null,
            'discount_started_at' => null,
            'discount_ended_at' => null,
        ]);

        return $result
            ? successResponse(null)
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::FAILED_OPERATION);
    }
}
