<?php

namespace App\Http\Controllers\Admin;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Models\CreditCard;
use App\Models\Setting;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;

class SettingController extends Controller
{
    public function showSupport()
    {
        $settings = [];
        $settings[Str::lower(Setting::MOBILE)] = Setting::query()->where('key', Setting::MOBILE)->first()?->value;
        $settings[Str::lower(Setting::PHONE)] = Setting::query()->where('key', Setting::PHONE)->first()?->value;
        $settings[Str::lower(Setting::ADDRESS)] = Setting::query()->where('key', Setting::ADDRESS)->first()?->translates;
        $settings[Str::lower(Setting::WORK_HOUR)] = Setting::query()->where('key', Setting::WORK_HOUR)->first()?->translates;

        $addressTranslates = [];
        foreach ($settings[Str::lower(Setting::ADDRESS)] as $translate) {
            $addressTranslates[$translate->language_locale] = [
                'value' => $translate->value ?? ''
            ];
        }
        $settings[Str::lower(Setting::ADDRESS)] = $addressTranslates;

        $wordHourTranslates = [];
        foreach ($settings[Str::lower(Setting::WORK_HOUR)] as $translate) {
            $wordHourTranslates[$translate->language_locale] = [
                'value' => $translate->value ?? ''
            ];
        }
        $settings[Str::lower(Setting::WORK_HOUR)] = $wordHourTranslates;

        return successResponse($settings);
    }

    public function updateSupport(Request $request)
    {
        $rules = [
            'mobile' => ['required', 'string'],
            'phone' => ['required', 'string'],
        ];

        foreach (app('languages') as $language) {
            $rules["address.{$language->locale}.value"] = ['required', 'string'];
            $rules["work_hour.{$language->locale}.value"] = ['required', 'string'];
        }

        $data = $request->validate($rules);
        return DB::transaction(function () use ($data) {
            Setting::query()->where('key', Setting::MOBILE)->first()?->update([
                'value' => $data['mobile']
            ]);

            Setting::query()->where('key', Setting::PHONE)->first()?->update([
                'value' => $data['phone']
            ]);

            $address = Setting::query()->where('key', Setting::ADDRESS)->first();

            if (!$address) {
                $address = Setting::query()->create(['key' => Setting::ADDRESS]);
            }
            foreach ($data['address'] as $locale => $values) {
                $address->translates()?->updateOrCreate(['language_locale' => $locale], ['value' => $values['value']]);
            }

            $work_hour = Setting::query()->where('key', Setting::WORK_HOUR)->first();

            if (!$work_hour) {
                $work_hour = Setting::query()->create(['key' => Setting::WORK_HOUR]);
            }
            foreach ($data['work_hour'] as $locale => $values) {
                $work_hour->translates()?->updateOrCreate(['language_locale' => $locale], ['value' => $values['value']]);
            }

            return successResponse(null);
        });
    }

    public function showCreditCurd()
    {
        $creditCurd = CreditCard::query()->whereNull('user_id')->first();

        return successResponse([
            'currency_code' => $creditCurd?->currency_code,
            'number' => $creditCurd?->number ?? '',
            'owner' => $creditCurd?->owner ?? '',
        ]);
    }

    public function updateCreditCurd(Request $request)
    {
        $rules = [
            'number' => ['required', 'string'],
            'owner' => ['required', 'string'],
        ];

        $data = $request->validate($rules);

        return DB::transaction(function () use ($data) {
            CreditCard::query()->whereNull('user_id')->updateOrCreate(['currency_code' => 'IQD'], ['user_id' => null] + $data);

            return successResponse(null);
        });
    }

    public function showWelcomeMessage()
    {
        $settings = [];
        $settings[Str::lower(Setting::WELCOME_MESSAGE)] = Setting::query()->where('key', Setting::WELCOME_MESSAGE)->first()?->translates;

        if (!$settings[Str::lower(Setting::WELCOME_MESSAGE)])
            return successResponse([]);

        $messageTranslates = [];
        foreach ($settings[Str::lower(Setting::WELCOME_MESSAGE)] as $translate) {
            $messageTranslates[$translate->language_locale] = [
                'value' => $translate->value ?? ''
            ];
        }
        $settings[Str::lower(Setting::WELCOME_MESSAGE)] = $messageTranslates;

        return successResponse($settings);
    }

    public function updateWelcomeMessage(Request $request)
    {
        $rules = [];

        foreach (app('languages') as $language) {
            $rules["welcome_message.{$language->locale}.value"] = ['required', 'string'];
        }

        $data = $request->validate($rules);
        return DB::transaction(function () use ($data) {
            $message = Setting::query()->where('key', Setting::WELCOME_MESSAGE)->first();

            if (!$message) {
                $message = Setting::query()->create(['key' => Setting::WELCOME_MESSAGE]);
            }

            foreach ($data['welcome_message'] as $locale => $values) {
                $message->translates()?->updateOrCreate(['language_locale' => $locale], ['value' => $values['value']]);
            }

            return successResponse(null);
        });
    }

    public function showGuideDescription()
    {
        $settings = [];
        $settings[Str::lower(Setting::GUIDE_DESCRIPTION)] = Setting::query()->where('key', Setting::GUIDE_DESCRIPTION)->first()?->translates;

        if (!$settings[Str::lower(Setting::GUIDE_DESCRIPTION)])
            return successResponse([]);
        $messageTranslates = [];
        foreach ($settings[Str::lower(Setting::GUIDE_DESCRIPTION)] as $translate) {
            $messageTranslates[$translate->language_locale] = [
                'value' => $translate->value ?? ''
            ];
        }
        $settings[Str::lower(Setting::GUIDE_DESCRIPTION)] = $messageTranslates;

        return successResponse($settings);
    }

    public function updateGuideDescription(Request $request)
    {
        $rules = [];

        foreach (app('languages') as $language) {
            $rules["guide_description.{$language->locale}.value"] = ['required', 'string'];
        }

        $data = $request->validate($rules);
        return DB::transaction(function () use ($data) {
            $message = Setting::query()->where('key', Setting::GUIDE_DESCRIPTION)->first();

            if (!$message) {
                $message = Setting::query()->create(['key' => Setting::GUIDE_DESCRIPTION]);
            }

            foreach ($data['guide_description'] as $locale => $values) {
                $message->translates()?->updateOrCreate(['language_locale' => $locale], ['value' => $values['value']]);
            }

            return successResponse(null);
        });
    }

    public function showAboutUsDescription()
    {
        $settings = [];
        $settings[Str::lower(Setting::ABOUT_US_DESCRIPTION)] = Setting::query()->where('key', Setting::ABOUT_US_DESCRIPTION)->first()?->translates;

        if (!$settings[Str::lower(Setting::ABOUT_US_DESCRIPTION)])
            return successResponse([]);
        $messageTranslates = [];
        foreach ($settings[Str::lower(Setting::ABOUT_US_DESCRIPTION)] as $translate) {
            $messageTranslates[$translate->language_locale] = [
                'value' => $translate->value ?? ''
            ];
        }
        $settings[Str::lower(Setting::ABOUT_US_DESCRIPTION)] = $messageTranslates;

        return successResponse($settings);
    }

    public function updateAboutUsDescription(Request $request)
    {
        $rules = [];

        foreach (app('languages') as $language) {
            $rules["about_us_description.{$language->locale}.value"] = ['required', 'string'];
        }

        $data = $request->validate($rules);
        return DB::transaction(function () use ($data) {
            $message = Setting::query()->where('key', Setting::ABOUT_US_DESCRIPTION)->first();

            if (!$message) {
                $message = Setting::query()->create(['key' => Setting::ABOUT_US_DESCRIPTION]);
            }

            foreach ($data['about_us_description'] as $locale => $values) {
                $message->translates()?->updateOrCreate(['language_locale' => $locale], ['value' => $values['value']]);
            }

            return successResponse(null);
        });
    }

    public function showProfit()
    {
        $settings = [];
        $settings[Str::lower(Setting::PUBLISHER_PROFIT)] = Setting::query()->valueOf(Setting::PUBLISHER_PROFIT)->first()?->value;
        $settings[Str::lower(Setting::MARKETER_PROFIT)] = Setting::query()->valueOf(Setting::MARKETER_PROFIT)->first()?->value;
        $settings[Str::lower(Setting::SITE_PROFIT)] = Setting::query()->valueOf(Setting::SITE_PROFIT)->first()?->value;

        return successResponse($settings);
    }

    public function updateProfit(Request $request)
    {
        $data = $request->validate([
            'publisher_profit' => ['required', 'integer', 'min:0', 'max:100'],
            'marketer_profit' => ['required', 'integer', 'min:0', 'max:100'],
            'site_profit' => ['required', 'integer', 'min:0', 'max:100']
        ]);

        $totalPercent = $data['publisher_profit'] + $data['marketer_profit'] + $data['site_profit'];

        if ($totalPercent > 100) {
            return failedResponse(trans('failed-messages.invalid_percent'), FailedResponseCode::FAILED_OPERATION);
        }

        return DB::transaction(function () use ($data) {

            Setting::query()->updateOrCreate(['key' => Setting::PUBLISHER_PROFIT], ['value' => $data['publisher_profit']]);
            Setting::query()->updateOrCreate(['key' => Setting::MARKETER_PROFIT], ['value' => $data['marketer_profit']]);
            Setting::query()->updateOrCreate(['key' => Setting::SITE_PROFIT], ['value' => $data['site_profit']]);

            Cache::forget('marketer_profit');

            return successResponse(null);
        });
    }

    public function showSocial()
    {
        $settings = [];
        $settings[Str::lower(Setting::TWITTER)] = Setting::query()->valueOf(Setting::TWITTER)->first()?->value;
        $settings[Str::lower(Setting::INSTAGRAM)] = Setting::query()->valueOf(Setting::INSTAGRAM)->first()?->value;
        $settings[Str::lower(Setting::YOUTUBE)] = Setting::query()->valueOf(Setting::YOUTUBE)->first()?->value;
        $settings[Str::lower(Setting::WHATSAPP)] = Setting::query()->valueOf(Setting::WHATSAPP)->first()?->value;
        $settings[Str::lower(Setting::TELEGRAM)] = Setting::query()->valueOf(Setting::TELEGRAM)->first()?->value;

        return successResponse($settings);
    }

    public function updateSocial(Request $request)
    {
        $data = $request->validate([
            'twitter' => ['nullable', 'url'],
            'instagram' => ['nullable', 'url'],
            'youtube' => ['nullable', 'url'],
            'whatsapp' => ['nullable', 'url'],
            'telegram' => ['nullable', 'url'],
        ]);

        return DB::transaction(function () use ($data) {

            Setting::query()->updateOrCreate(['key' => Setting::TWITTER], ['value' => $data['twitter']]);
            Setting::query()->updateOrCreate(['key' => Setting::INSTAGRAM], ['value' => $data['instagram']]);
            Setting::query()->updateOrCreate(['key' => Setting::YOUTUBE], ['value' => $data['youtube']]);
            Setting::query()->updateOrCreate(['key' => Setting::WHATSAPP], ['value' => $data['whatsapp']]);
            Setting::query()->updateOrCreate(['key' => Setting::TELEGRAM], ['value' => $data['telegram']]);

            return successResponse(null);
        });
    }

    public function showFooterMessage()
    {
        $settings = [];
        $settings[Str::lower(Setting::FOOTER_TITLE)] = Setting::query()->where('key', Setting::FOOTER_TITLE)->first()?->translates;
        $settings[Str::lower(Setting::FOOTER_DESCRIPTION)] = Setting::query()->where('key', Setting::FOOTER_DESCRIPTION)->first()?->translates;

        $messageTranslates = [];
        foreach ($settings[Str::lower(Setting::FOOTER_TITLE)] as $translate) {
            $messageTranslates[$translate->language_locale] = [
                'value' => $translate->value ?? ''
            ];
        }
        $settings[Str::lower(Setting::FOOTER_TITLE)] = $messageTranslates;

        $descriptionTranslates = [];
        foreach ($settings[Str::lower(Setting::FOOTER_DESCRIPTION)] as $translate) {
            $descriptionTranslates[$translate->language_locale] = [
                'value' => $translate->value ?? ''
            ];
        }
        $settings[Str::lower(Setting::FOOTER_DESCRIPTION)] = $descriptionTranslates;

        return successResponse($settings);
    }

    public function updateFooterMessage(Request $request)
    {
        $rules = [];

        foreach (app('languages') as $language) {
            $rules["footer_title.{$language->locale}.value"] = ['required', 'string'];
            $rules["footer_description.{$language->locale}.value"] = ['required', 'string'];
        }

        $data = $request->validate($rules);
        return DB::transaction(function () use ($data) {
            $title = Setting::query()->where('key', Setting::FOOTER_TITLE)->first();

            if (!$title) {
                $title = Setting::query()->create(['key' => Setting::FOOTER_TITLE]);
            }

            foreach ($data['footer_title'] as $locale => $values) {
                $title->translates()?->updateOrCreate(['language_locale' => $locale], ['value' => $values['value']]);
            }

            $description = Setting::query()->where('key', Setting::FOOTER_DESCRIPTION)->first();

            if (!$description) {
                $description = Setting::query()->create(['key' => Setting::FOOTER_DESCRIPTION]);
            }

            foreach ($data['footer_description'] as $locale => $values) {
                $description->translates()?->updateOrCreate(['language_locale' => $locale], ['value' => $values['value']]);
            }

            return successResponse(null);
        });
    }
}
