<?php

namespace App\Http\Controllers\Admin;

use App\Filters\Admin\SortBy;
use App\Filters\Admin\Transaction\Type;
use App\Filters\CreatedAt;
use App\Filters\CreatedAtFrom;
use App\Filters\CreatedAtTo;
use App\Filters\Status;
use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Resources\Admin\TransactionResource;
use App\Http\Resources\PaginateCollection;
use App\Models\Transaction;
use Illuminate\Http\Request;
use Illuminate\Pipeline\Pipeline;
use Illuminate\Validation\Rule;

class TransactionController extends Controller
{
    public function __construct()
    {
        $this->middleware('can:TRANSACTIONS_LIST')->only(['index']);
        $this->middleware('can:TRANSACTIONS_UPDATE')->only(['changeStatus']);
    }

    public function index()
    {
        $transactions = app(Pipeline::class)
            ->send(Transaction::query()->with(['currency', 'user' => fn($q) => $q->withTrashed()]))
            ->through([
                Type::class,
                Status::class,
                CreatedAt::class,
                CreatedAtFrom::class,
                CreatedAtTo::class,
                SortBy::class
            ])->thenReturn()
            ->paginate(\request('per_page') ?? 15);

        return successResponse(new PaginateCollection($transactions, TransactionResource::class));
    }

    public function changeStatus(Request $request, Transaction $transaction)
    {
        $data = $request->validate([
            'status' => ['required', 'string', Rule::in([Transaction::SUCCESS, Transaction::FAILED, Transaction::PAYMENT, Transaction::CHECKING])]
        ]);

        return $transaction->update($data)
            ? successResponse(null)
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::FAILED_OPERATION);
    }
}
