<?php

namespace App\Http\Controllers;

use App\Helper\Enum;
use App\Http\Resources\CollaboratorResource;
use App\Models\Collaborator;
use Illuminate\Http\Request;

class CollaboratorController extends Controller
{
    public function index(string|null $collaboratorType = null)
    {
        $query = Collaborator::query();

        $query = match ($collaboratorType) {
            Collaborator::AUTHOR => $query->author(),
            Collaborator::TRANSLATOR => $query->translator(),
            Collaborator::SPEAKER => $query->speaker(),
            default => $query
        };

        $query->when(\request('q'), function ($q) {
            $q->whereHas('translates', function ($q) {
                $q->where('name', 'LIKE', '%' . \request('q') . '%');
            });
        });

        if (($user = auth()->user()) && $user->role === Enum::PUBLISHER) {
            $query->activeOrBelongsTo($user->id);
        } else {
            $query->active();
        }


        $query->when(\request('limit'), function ($q) {
            $q->limit(\request('limit'));
        });

        return successResponse([
            'collaborators' => CollaboratorResource::collection($query->get())
        ]);
    }
}
