<?php

namespace App\Http\Controllers;

use App\Http\Requests\ContactUsRequest;
use App\Http\Resources\FAQGroupResource;
use App\Http\Resources\SettingResource;
use App\Mail\ContactUsMail;
use App\Models\ContactUs;
use App\Models\FAQGroup;
use App\Models\Setting;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class ContactUsController extends Controller
{
    public function index()
    {
        return successResponse([
            'settings' => Setting::valueOfCombined([Setting::ADDRESS, Setting::MOBILE, Setting::PHONE, Setting::WORK_HOUR]),
            'faq_groups' => FAQGroupResource::collection(FAQGroup::with(['faqs'])->get())
        ]);
    }

    public function store(ContactUsRequest $request)
    {
        $request->validated();

        if ($file = $request->file('file')) {
            $path = Storage::putFile('/contact_us', $file);
        }

        $contactUs = ContactUs::create([
            'user_id' => auth()?->id(),
            'os' => $request->os,
            'title' => $request->title,
            'problem' => $request->problem,
            'description' => $request->description,
            'country_code' => $request->country_code,
            'mobile' => $request->mobile,
            'email' => $request->email,
            'file_path' => $path ?? null
        ]);

        return successResponse([
            'id' => $contactUs->id,
            'os' => Str::lower($contactUs->os),
            'title' => $contactUs->title,
            'problem' => $contactUs->problem,
            'description' => $contactUs->description,
            'country_code' => $contactUs->country_code,
            'mobile' => $contactUs->mobile,
            'email' => $contactUs->email,
        ]);
    }
}
