<?php

namespace App\Http\Controllers;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Models\Imageable;
use App\Models\User;
use App\Traits\FileUploaderTrait;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class DocumentController extends Controller
{
    use FileUploaderTrait;

    protected function rules()
    {
        return [
            'document' => ['required', 'image']
        ];
    }

    protected function path()
    {
        $year = now()->year;
        return "/documents/{$year}";
    }

    protected function fieldName(): string
    {
        return 'document';
    }

    public function destroy($imageableId)
    {
        $imageable = Imageable::query()->findOrFail($imageableId);
        abort_if(!auth('admin')->check() && ($imageable->imageable_id != auth()->id() || $imageable->imageable_type != User::class), 404, 'Not Found');
        Storage::delete($imageable->path);
        $imageable->delete();
        return successResponse(null);
    }
}
