<?php

namespace App\Http\Controllers;

use App\Facades\DeviceToken;
use App\Helper\Enum;
use App\Helper\FailedResponseCode;
use App\Http\Resources\Marketer\MarketerResource;
use App\Http\Resources\Publisher\PublisherResource;
use App\Http\Resources\User\UserResource;
use App\Models\Device;
use App\Models\User;
use App\Services\DeviceService;
use Illuminate\Http\Request;

class MaxDeviceController extends Controller
{
    public function destroy(Device $device, $token)
    {
        abort_if(!DeviceToken::exists($token), 404, 'Not Found');

        $data = DeviceToken::get($token);

        abort_if(!isset($data['id']) || !isset($data['role']) || $device->user_id != $data['id'], 404, 'Not Found');

        if ($device->ip == \request()->ip()) {
            return failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::UNABLE_TO_DISCONNECT_DEVICE);
        }

        $user = User::query()->where('role', $data['role'])->findOrFail($data['id']);

        $status = $device->delete();

        if (!$status || !$user) {
            return failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::UNABLE_TO_DISCONNECT_DEVICE);
        }

        DeviceService::connect($user);

        switch ($user->role) {
            case Enum::PUBLISHER:
                $user->load(['publisherProfile', 'documents']);
                $user = new PublisherResource($user);
                break;
            case Enum::MARKETER:
                $user->load(['documents']);
                $user = new MarketerResource($user);
                break;
            default:
                $user = new UserResource($user);
                break;
        }

        return successResponse([
            'user' => $user,
            'token' => $user->createToken('user auth token', ['user-access'])->accessToken
        ]);

    }
}
