<?php

namespace App\Http\Controllers;

use App\Http\Resources\PaginateCollection;
use App\Http\Resources\ShowProductCommentResource;
use App\Models\Comment;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Pagination\LengthAwarePaginator;

class ProductCommentController extends Controller
{
    public function index(Product $product)
    {
        if ($product->is_limited_country) {
            return successResponse(new PaginateCollection(new LengthAwarePaginator(collect([]),0,10,1), ShowProductCommentResource::class));
        }

        $userId = auth()->id();
        $comments = Comment::with([
            'commentable',
            'replies' => fn($replyQuery) => $replyQuery->with(['votes' => fn($voteQuery) => $userId ? $voteQuery->wherePivot('user_id', $userId) : $voteQuery->where('user_id', 0), 'commentable'])->approved(),
            'votes' => fn($voteQuery) => $userId ? $voteQuery->wherePivot('user_id', $userId) : $voteQuery->where('user_id', 0)
        ])
            ->whereNull('comment_id')->where('product_id', $product->id)->approved()->paginate(10);

        return successResponse(new PaginateCollection($comments, ShowProductCommentResource::class));
    }
}
