<?php

namespace App\Http\Controllers\Publisher;

use App\Helper\Enum;
use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Resources\Publisher\CollaboratorResource;
use App\Models\Collaborator;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;

class CollaboratorController extends Controller
{
    public function index(string $collaboratorType): JsonResponse
    {
        $collaborators = Collaborator::query()
            ->where(function ($q) {
                $q->where('publisher_id', auth()->id())
                    ->orWhere('status', Enum::STATUS_ACTIVE);
            })
            ->where('type', $collaboratorType)
            ->when(request('name'), function ($q) {
                $q->whereHas('translates', function ($q) {
                    $q->where('name', 'LIKE', '%' . request('name') . '%');
                });
            })
            ->limit(50)
            ->get();

        return successResponse([
            Str::lower($collaboratorType) => CollaboratorResource::collection($collaborators)
        ]);
    }

    public function store(Request $request, string $collaboratorType): JsonResponse
    {
        $request->validate([
            'name' => ['required', 'string', 'min:4']
        ]);

        $collaborator = DB::transaction(function () use ($collaboratorType) {
            $collaborator = auth()->user()->collaborators()->create([
                'type' => $collaboratorType,
                'status' => Enum::STATUS_PENDING
            ]);

            $collaborator->translates()->create([
                'language_locale' => app()->getLocale(),
                'name' => \request('name')
            ]);

            return $collaborator;
        });

        return $collaborator
            ? successResponse([
                'collaborator' => new CollaboratorResource($collaborator)
            ])
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::FAILED_TO_CREATE_COLLABORATOR);
    }
}
