<?php

namespace App\Http\Controllers\Publisher;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Requests\CollectionRequest;
use App\Http\Resources\Publisher\CollectionResource;
use App\Models\Collection;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

class CollectionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return JsonResponse
     */
    public function index()
    {
        return successResponse([
            'collaborators'=>CollectionResource::collection(auth()->user()->collections)
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param CollectionRequest $request
     * @return JsonResponse
     */
    public function store(CollectionRequest $request)
    {
        $collection = auth()->user()->collections()->create();
        $collection->translates()->create($request->validated());
        return successResponse(new CollectionResource($collection));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param Collection $collection
     * @return JsonResponse
     */
    public function update(CollectionRequest $request, Collection $collection)
    {
        abort_if(auth()->id() != $collection->publisher_id, Response::HTTP_NOT_FOUND, 'Not Found');
        if ($collection->currentTranslate)
            $status = $collection->currentTranslate->update($request->validated());
        else {
            $status = !!$collection->translates()->create($request->validated());
        }

        return $status
            ? successResponse(new CollectionResource($collection))
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::UPDATE_FAILED);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param Collection $collection
     * @return JsonResponse
     */
    public function destroy(Collection $collection)
    {
        abort_if(auth()->id() != $collection->publisher_id, Response::HTTP_NOT_FOUND, 'Not Found');

        return $collection->delete()
            ? successResponse(null)
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::UPDATE_FAILED);
    }
}
