<?php

namespace App\Http\Controllers\Publisher;

use App\Helper\Enum;
use App\Http\Controllers\Controller;
use App\Models\Imageable;
use App\Models\User;
use App\Traits\FileUploaderTrait;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class LogoController extends Controller
{
    use FileUploaderTrait;


    protected function beforeStore(string $path): JsonResponse|null
    {
        $user = auth()->user();

        if (!$user || $user->role !== Enum::PUBLISHER)
            return null;

        $user->load('publisherProfile');

        if($user->publisherProfile){
            Storage::delete($user->publisherProfile->publisher_logo);
            $user->publisherProfile->update([
                'publisher_logo' => $path
            ]);

            return successResponse([
                'path' => $path,
                'url' => $user->publisherProfile->logo_url
            ]);
        }


        return successResponse([
            'path' => $path,
            'url' => null
        ]);
    }

    protected function rules()
    {
        return [
            'logo' => ['required', 'image']
        ];
    }

    protected function path(): string
    {
        $year = now()->year;
        return "/logo/{$year}";
    }

    protected function fieldName(): string
    {
        return 'logo';
    }
}
