<?php

namespace App\Http\Controllers\Publisher;

use App\Http\Controllers\Controller;
use App\Http\Resources\PaginateCollection;
use App\Http\Resources\Publisher\OrderRecordResource;
use App\Models\OrderProduct;
use Illuminate\Http\Request;
use Illuminate\Pipeline\Pipeline;

class OrderRecordController extends Controller
{
    public function index()
    {
        $publisher = auth()->user();

        $orderProducts = OrderProduct::query()->with('order')->whereHas('order', fn($q) => $q->paid())
            ->whereHas('product.publisher', fn($q) => $q->where('users.id', $publisher->id));

        $orderProducts = app(Pipeline::class)
            ->send($orderProducts)
            ->through([
                \App\Filters\SortBy::class,
            ])->thenReturn()
            ->paginate(30);

        return successResponse([
            'orders_records' => new PaginateCollection($orderProducts, OrderRecordResource::class)
        ]);
    }
}
