<?php

namespace App\Http\Controllers\Publisher;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Requests\Publisher\ProductFileRequest;
use App\Models\Product;
use App\Models\ProductFile;
use App\Services\Publisher\ProductFileService;
use Illuminate\Http\JsonResponse;
use Illuminate\Support\Facades\Storage;

class ProductFileController extends Controller
{
    public function store(ProductFileRequest $request, ProductFileService $service): JsonResponse
    {
        $request->validated();

        $result = $service->setProductType($request->product_type)
            ->setProductFileType($request->product_file_type)
            ->storeAndUpdate($request->file('product_file'));

        return $result
            ? successResponse($result)
            : failedResponse(trans('failed-messages.file_upload_storage_failed'), FailedResponseCode::FILE_STORE_FAILED);

    }

    public function update(ProductFileRequest $request, ProductFile $productFile, ProductFileService $service): JsonResponse
    {
        $publisher = auth()->user();

        abort_if($publisher->id != $productFile->publisher_id, 404, 'Not Found');

        $disk = $request->product_file_type == Product::MAIN_FILE ? 'product' : 'public';
        if (Storage::disk($disk)->exists($productFile->path)) {
            Storage::disk($disk)->delete($productFile->path);
        }

        $result = $service->setProductType($request->product_type)
            ->setProductFileType($request->product_file_type)
            ->setProductFile($productFile)
            ->storeAndUpdate($request->file('product_file'));

        return $result
            ? successResponse($result)
            : failedResponse(trans('failed-messages.file_upload_storage_failed'), FailedResponseCode::FILE_STORE_FAILED);

    }

    public function destroy(ProductFile $productFile, ProductFileService $service): JsonResponse
    {
        $publisher = auth()->user();

        abort_if($publisher->id != $productFile->publisher_id, 404, 'Not Found');

        $disk = $productFile->type == Product::MAIN_FILE ? 'product' : 'public';

        $result = true;
        if (Storage::disk($disk)->exists($productFile->path)) {
            $result = Storage::disk($disk)->delete($productFile->path);
        }

        return $result
            ? successResponse(null)
            : failedResponse(trans('failed-messages.file_delete_failed'), FailedResponseCode::FILE_DELETE_FAILED);

    }
}
