<?php

namespace App\Http\Controllers\Publisher;

use App\Helper\Enum;
use App\Http\Controllers\Controller;
use App\Http\Resources\CurrencyResource;
use App\Models\Currency;
use App\Models\Order;
use App\Models\OrderProduct;
use App\Models\ProfitWithdrawReport;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

class SaleRecordController extends Controller
{
    public function index()
    {
        $currency = Str::upper(\request('currency', Currency::query()->first()->currency));
        $publisher = auth()->user();
        $publisher?->load(['profit']);

        $lastProfitReport = ProfitWithdrawReport::query()
            ->where('currency_code', $currency)
            ->where('client_id', $publisher->id)
            ->latest()->first();

        $orderProducts = OrderProduct::query()->with(['product', 'translate', 'order'])
            ->whereHas('product.publisher', function ($q) use ($publisher) {
                $q->where('id', $publisher->id);
            })
            ->whereHas('order', function ($q) use ($currency) {
                $q->where('status', Order::PAID)->where('currency_code', $currency);
            })
            ->orderBy('created_at', \request('sort_by') && Str::upper(\request('sort_by')) === 'ASC' ? 'ASC' : 'DESC')
            ->get();

        $withdrawable = OrderProduct::query()->with(['order'])
            ->whereHas('product.publisher', function ($q) use ($publisher) {
                $q->where('id', $publisher->id);
            })
            ->whereHas('order', function ($q) use ($currency, $lastProfitReport) {
                $q->where('status', Order::PAID)->where('currency_code', $currency);
                if ($lastProfitReport)
                    $q->where('paid_at', '>', $lastProfitReport->created_at);
            })->sum('total_price');

        $orderProductResource = $orderProducts->map(function ($orderProduct) use ($publisher, $lastProfitReport) {
            return [
                'product' => [
                    'title' => $orderProduct?->translate?->title,
                    'slug' => $orderProduct?->translate?->slug,
                    'cover_url' => $orderProduct?->translate?->cover_url
                ],
                'order' => [
                    'number' => $orderProduct?->order?->order_number,
                    'paid_at' => $orderProduct?->order?->paid_at,
                ],
                'price' => $orderProduct->price,
                'discount' => $orderProduct->discount,
                'total_price' => $orderProduct->total_price,
                'profit' => number_format($orderProduct->total_price * ($publisher?->profit->profit / 100)),
                'is_withdrawn' => $lastProfitReport && $orderProduct?->order?->paid_at->lt($lastProfitReport->created_at)
            ];
        });

        return successResponse([
            'currencies' => CurrencyResource::collection(Currency::query()->get()),
            'records' => $orderProductResource,
            'total_record' => number_format($orderProducts->sum('total_price') * ($publisher?->profit->profit / 100)),
            'withdrawable_record' => number_format($withdrawable * ($publisher?->profit->profit / 100))
        ]);
    }
}
