<?php

namespace App\Http\Controllers;

use App\Helper\FailedResponseCode;
use App\Http\Requests\User\AllReaderPercentRequest;
use App\Http\Requests\User\ReaderPercentRequest;
use App\Models\Product;
use App\Models\ReaderPercent;
use Illuminate\Http\Request;

class ReaderPercentController extends Controller
{
    public function store(ReaderPercentRequest $request, Product $product)
    {
        $user = auth()->user();

        $productLanguage = $product->translates()->where('language_locale', $request->product_lang)->first();

        if (!$productLanguage) {
            return abort(404, 'Not Found');
        }

        if ($productLanguage->purchase_type !== Product::FREE) {
            $orderProduct = $user->orderProducts()->whereNotNull('order_id')
                ->where('product_id', $product->id)
                ->where('product_language_id', $productLanguage->id)
                ->where('type', $request->product_type)
                ->first();

            if (!$orderProduct)
                return failedResponse(trans('failed-messages.product_not_purchased'), FailedResponseCode::PRODUCT_NOT_PURCHASED);
        }

        $reader = $user->readers()->where([
            'product_id' => $product->id,
            'product_language_id' => $productLanguage->id,
            'type' => $request->product_type
        ])->first();

        if (!$reader) {

            $user->readers()->create([
                'product_id' => $product->id,
                'product_language_id' => $productLanguage->id,
                'type' => $request->product_type,
                'percent' => $request->value,
                'location' => $request->location || null
            ]);
            return successResponse(null);
        }

        if ($request->value > $reader->percent) {
            $reader->update([
                'percent' => $request->value,
                'location' => $request->location
            ]);
            return successResponse(null);
        }

        $reader->update([
            'location' => $request->location
        ]);
        return successResponse(null);
    }

    public function storeAll(AllReaderPercentRequest $request)
    {
        $user = auth()->user();
        $readingPercents = collect($request->validated()['value']);
        $readingPercents = $readingPercents->groupBy(['id', 'product_type']);
        $newReadingPercents = [];
//        foreach ($readingPercents as $id => $items) {
//            foreach ($items as $type => $typeItems) {
//                $time = 0;
//                foreach ($typeItems as $item) {
//                    $time += $item['time'];
//                }
//
//                $newReadingPercents[$id][$type] = $time;
//            }
//        }
        return successResponse([]);
    }
}
