<?php

namespace App\Http\Controllers;

use App\Models\Product;
use App\Models\Setting;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

class SiteSettingController extends Controller
{
    public function index()
    {
        $recommendedProducts = Product::query()->mostPurchased()->limit(6)->get();
        $requiredSettings = Setting::query()->whereIn('key', [
            Setting::SUPPORT_TIME,
            Setting::PHONE,
            Setting::TWITTER,
            Setting::INSTAGRAM,
            Setting::YOUTUBE,
            Setting::WHATSAPP,
            Setting::TELEGRAM,
            Setting::FOOTER_TITLE,
            Setting::FOOTER_DESCRIPTION,
            Setting::ADDRESS,
            Setting::MOBILE,
            Setting::WORK_HOUR,
        ])->get();

        $settings = [];

        foreach ($requiredSettings as $setting) {
            $settings[Str::lower($setting->key)] = $setting?->value ?? $setting->translate?->value;
        }

        $products = [];

        foreach ($recommendedProducts as $product) {
            $products[] = [
                'id' => $product->id,
                'title' => $product->translate?->title,
                'slug' => $product->translate?->slug,
                'type' => $product->type
            ];
        }

        return successResponse([
            'recommended_products' => $products,
            'settings' => $settings
        ]);
    }
}
