<?php

namespace App\Http\Controllers\User\Auth;

use App\Helper\Enum;
use App\Helper\FailedResponseCode;
use App\Helper\ReferralGenerator;
use App\Http\Controllers\Controller;
use App\Http\Resources\User\UserResource;
use App\Models\User;
use App\Services\DeviceService;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Laravel\Socialite\Facades\Socialite;

class GoogleController extends Controller
{
    public function callback(Request $request)
    {
        if (!$request->has('code')) {
            return failedResponse(trans('failed-messages.google_login_failed'), FailedResponseCode::GOOGLE_LOGIN_FAILED);
        }

        $user = Socialite::driver('google')->stateless()->user();

        $email = $user->getEmail();
        $user = User::query()->where('email', $email)->whereUser()->first();

        if (!$user) {
            $user = User::create([
                'role' => Enum::USER,
                'register_type' => Enum::REGISTER_TYPE_GOOGLE,
                'email' => $email,
                'email_verified_at' => now(),
                'password' => bcrypt(Str::random(8)),
                'referral_code' => ReferralGenerator::generate()
            ]);
//            return failedResponse(trans('failed-messages.user_email_not_found'), FailedResponseCode::INVALID_CREDENTIALS);
        }

        DeviceService::connect($user);

        return successResponse([
            'user' => new UserResource($user),
            'token' => $user->createToken('user auth token', ['user-access'])->accessToken
        ]);
    }
}
