<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Http\Resources\PaginateCollection;
use App\Http\Resources\ProductResource;
use App\Models\Product;
use Illuminate\Http\Request;

class BookIntroductionController extends Controller
{
    public function index()
    {
//        $products = Product::query()->whereHas('orders', function ($q) {
//            $q->where('orders.user_id', auth()->id())->paid();
//        })
//            ->join('order_products', 'order_products.product_id', '=', 'products.id')
//            ->join('orders', 'order_products.order_id', '=', 'orders.id')
//            ->join('users','users.id','=','orders.user_id')
//            ->orderBy('orders.paid_at', 'desc')
//            ->get();

        $products = Product::query()->whereHas('orders', function ($q) {
            $q->where('orders.user_id', auth()->id())->paid();
        })->limit(30)->latest()->get();

        $categories = $products->pluck('sub_category_id')->unique();
        $publishers = $products->pluck('publisher_id')->unique();
        $genres = $products->pluck('genre_id')->unique();
        $types = $products->pluck('type')->unique();
        $secondaryType = $products->where('secondary_type', Product::AUDIO_BOOK)->first()?->secondary_type;

        $products = Product::query()->dataSummary()
            ->whereIn('sub_category_id', $categories)
            ->orWhereIn('publisher_id', $publishers)
            ->orWhereIn('genre_id', $genres)
            ->orWhereIn('type', $types);

        if ($secondaryType) {
            $products->orWhere('secondary_type', $secondaryType);
        }

        $products = $products->active()->inRandomOrder()->limit(30)->get();

        if (!$products->count()) {
            $products = Product::query()->dataSummary()->active()->latest()->limit(30)->get();
        }

        return successResponse([
            'products' => ProductResource::collection($products)
        ]);
    }
}
