<?php

namespace App\Http\Controllers\User;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Requests\User\CommentRequest;
use App\Models\Comment;
use App\Models\Product;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

class CommentController extends Controller
{
    public function store(CommentRequest $request, Product $product): JsonResponse
    {
        $comment = auth()->user()?->comments()->create($request->validated() + ['product_id' => $product->id]);

        return successResponse([
            'id' => $comment->id,
            'title' => $comment->title,
            'comment' => $comment->comment,
        ]);
    }

    public function storeReply(CommentRequest $request, Product $product, Comment $comment): JsonResponse
    {
        abort_if($comment->product_id != $product->id || $comment->status !== Comment::APPROVED, 404, 'Not Found');

        $reply = auth()->user()?->comments()->create($request->validated() + ['comment_id' => $comment->id, 'product_id' => $product->id]);

        return successResponse([
            'id' => $reply->id,
            'title' => $reply->title,
            'comment' => $reply->comment,
        ]);
    }

    public function storeVote(Request $request, Comment $comment): JsonResponse
    {
        abort_if($comment->status !== Comment::APPROVED, 404, 'Not Found');

        $request->validate([
            'like' => ['required', 'integer', 'in:0,1']
        ]);

        $user = auth()->user();

        if (app()->environment() === 'production' && $user->id == $comment->user_id)
            return failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::FAILED_OPERATION);

        $vote = $user->votedComments()->wherePivot('like', $request->like)->wherePivot('comment_id', $comment->id)->first()?->pivot;

        if ($vote && $vote->like == $request->like)
            $comment->votes()->detach($user->id);
        else
            $comment->votes()->syncWithoutDetaching([$user->id => ['like' => $request->like, 'ip' => request()->ip()]]);

        return successResponse(null);
    }
}
