<?php

namespace App\Http\Controllers\User;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Requests\User\HighlightRequest;
use App\Http\Resources\User\HighlightResource;
use App\Models\Highlight;
use App\Models\Product;
use App\Models\ProductLanguage;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

class HighlightController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return JsonResponse
     */
    public function index(ProductLanguage $productLanguage)
    {
        $productLanguage->load(['highlights' => fn($q) => $q->where('user_id', auth()->id())]);

        return successResponse(HighlightResource::collection($productLanguage->highlights));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function store(HighlightRequest $request, ProductLanguage $productLanguage)
    {
        $highlight = $productLanguage->highlights()->create($request->validated() + ['user_id' => auth()->id()]);

        return successResponse(new HighlightResource($highlight));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param Highlight $highlight
     * @return JsonResponse
     */
    public function destroy(ProductLanguage $productLanguage, Highlight $highlight)
    {
        abort_if($highlight->user_id != auth()->id() || $highlight->product_language_id != $productLanguage->id, 404, 'Not Found');

        return $highlight->delete()
            ? successResponse(null)
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::FAILED_OPERATION);
    }
}
