<?php

namespace App\Http\Controllers\User;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Requests\User\HighlightRequest;
use App\Http\Requests\User\NoteRequest;
use App\Http\Resources\User\HighlightResource;
use App\Http\Resources\User\NoteResource;
use App\Models\Highlight;
use App\Models\Note;
use App\Models\Product;
use App\Models\ProductLanguage;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

class NoteController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return JsonResponse
     */
    public function index(ProductLanguage $productLanguage)
    {
        $productLanguage->load(['notes' => fn($q) => $q->where('user_id', auth()->id())]);

        return successResponse(NoteResource::collection($productLanguage->notes));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param NoteRequest $request
     * @param ProductLanguage $productLanguage
     * @return JsonResponse
     */
    public function store(NoteRequest $request, ProductLanguage $productLanguage)
    {
        $note = $productLanguage->notes()->create($request->validated() + ['user_id' => auth()->id()]);

        return successResponse(new NoteResource($note));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param NoteRequest $request
     * @param ProductLanguage $productLanguage
     * @param Note $note
     * @return JsonResponse
     */
    public function update(NoteRequest $request, ProductLanguage $productLanguage, Note $note)
    {
        abort_if($note->user_id != auth()->id() || $note->product_language_id != $productLanguage->id, 404, 'Not Found');

        $note->update($request->validated());

        return successResponse(new NoteResource($note));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param Note $note
     * @return JsonResponse
     */
    public function destroy(ProductLanguage $productLanguage, Note $note)
    {
        abort_if($note->user_id != auth()->id() || $note->product_language_id != $productLanguage->id, 404, 'Not Found');

        return $note->delete()
            ? successResponse(null)
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::FAILED_OPERATION);
    }
}
