<?php

namespace App\Http\Controllers\User;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Requests\User\OrderRequest;
use App\Http\Resources\User\PurchaseProductResource;
use App\Models\Currency;
use App\Models\Order;
use App\Models\Transaction;
use App\Services\PaymentService;
use App\Services\User\OrderService;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Shetabit\Multipay\Invoice;
use Shetabit\Payment\Facade\Payment;

class OrderController extends Controller
{
    public function store(OrderRequest $request, OrderService $service)
    {
        $data = (object)$request->validated();

        $user = auth()->user();

        $user->load([
            'orderProducts' => fn($q) => $q->with('product')->whereNull('order_id')->orWhereHas('order', fn($q) => $q->notPaid()),
            'currentOrder'
        ]);

        $prices = $service->getPrices($user->orderProducts, $data->currency, $data->discount ?? null);
        $service->updateOrderProductPrices($user->orderProducts, $prices);

        if ($request->wallet) {
            $paymentInfo = PaymentService::walletPayment($user, $data);
            if (!$paymentInfo)
                return failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::TRANSACTION_FAILED);

            return successResponse(null);
        }

        $paymentInfo = PaymentService::gatewayPayment($user, $data);

        if (!$paymentInfo)
            return failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::TRANSACTION_FAILED);

        return successResponse([
            'link' => $paymentInfo
        ]);
    }
}
