<?php

namespace App\Http\Controllers\User\Profile;

use App\Http\Controllers\Controller;
use App\Http\Resources\PaginateCollection;
use App\Http\Resources\User\LibraryResource;
use App\Http\Resources\User\PurchaseProductResource;
use App\Models\Library;
use App\Models\OrderProduct;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Pipeline\Pipeline;

class LibraryController extends Controller
{
    public function index(string $productVariant = null)
    {
        $user = auth()->user();

        if ($productVariant) {
            $libraries = app(Pipeline::class)
                ->send(Library::dataSummary($user->id)->where('type',$productVariant))
                ->through([
                    \App\Filters\SortBy::class,
                ])->thenReturn()
                ->paginate(30);

            return successResponse([
                'products' => new PaginateCollection($libraries, LibraryResource::class)
            ]);
        }

        $electronicBooks = Library::dataSummary($user->id)
            ->electronicBook()
            ->latest()
            ->limit(15)
            ->get();

        $audioBooks = Library::dataSummary($user->id)
            ->audioBook()
            ->latest()
            ->limit(15)
            ->get();

        $podcasts = Library::dataSummary($user->id)
            ->podcast()
            ->latest()
            ->limit(15)
            ->get();

        $magazines = Library::dataSummary($user->id)
            ->magazine()
            ->latest()
            ->limit(15)
            ->get();

        return successResponse([
            'electronic_book' => LibraryResource::collection($electronicBooks),
            'audio_book' => LibraryResource::collection($audioBooks),
            'podcast' => LibraryResource::collection($podcasts),
            'magazine' => LibraryResource::collection($magazines),
        ]);
    }

    public function destroy(Library $library)
    {
        abort_if($library->user_id != auth()->id(), 404, 'Not Found');

        return $library->delete()
            ? successResponse(null)
            : failedResponse(null, trans('failed-messages.failed_operation'));
    }
}
