<?php

namespace App\Http\Controllers\User\Profile;

use App\Http\Controllers\Controller;
use App\Http\Resources\PaginateCollection;
use App\Http\Resources\User\LibraryResource;
use App\Http\Resources\User\PurchaseProductResource;
use App\Models\Library;
use App\Models\OrderProduct;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Pipeline\Pipeline;

class MobileLibraryController extends Controller
{
    public function index()
    {
        $user = auth()->user();
        $libraries = Library::query()->with(['product' => fn($q) => $q->withTrashed(), 'productLanguage' => function ($q) {
            $q->with(['collaborators', 'files'])->withTrashed();
        }])->where('user_id', $user->id)->paginate(30);

        return successResponse([
            'products' => new PaginateCollection($libraries, LibraryResource::class)
        ]);
    }

    public function indexCount()
    {
        $user = auth()->user();
        $user->loadCount('bookmarkedProducts');

        $electronicBooksCount = Library::query()->where('user_id', $user->id)->electronicBook()->count();
        $audioBooksCount = Library::query()->where('user_id', $user->id)->audioBook()->count();
        $podcastsCount = Library::query()->where('user_id', $user->id)->podcast()->count();
        $magazinesCount = Library::query()->where('user_id', $user->id)->magazine()->count();

        return successResponse([
            'electronic_book' => $electronicBooksCount,
            'audio_book' => $audioBooksCount,
            'podcast' => $podcastsCount,
            'magazine' => $magazinesCount,
            'favorite' => $user->bookmarked_products_count,
        ]);
    }
}
