<?php

namespace App\Http\Controllers\User\Profile;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use App\Http\Requests\User\ProfileRequest;
use App\Services\Auth\OTPService;
use App\Services\User\Profile\ProfileService;
use Illuminate\Support\Facades\Crypt;

class ProfileController extends Controller
{
    public function update(ProfileRequest $request, ProfileService $service)
    {
        $user = auth()->user();

        $data = (object)$request->validated();
        $service->setData($data)->setUser($user);

        if (isset($data->email) && $data->email !== $user->email) {
            if (!isset($data->otp)) {
                return successResponse([
                    'code' => OTPService::sendCode(['email' => $data->email], "profile_user_$data->email"),
                    'type' => 'EMAIL',
                    'status' => 'OTP'
                ]);
            }
            $status = $service->verify($data->email)->updateEmail();
        } elseif ((isset($data->mobile) && isset($data->country_code)) && ($data->mobile != $user->mobile || $data->country_code != $user->country_code)) {
            if (!isset($data->otp)) {
                return successResponse([
                    'code' => OTPService::sendCode(['mobile' => $data->mobile, 'country_code' => $data->country_code], "profile_user_$data->mobile"),
                    'type' => 'MOBILE',
                    'status' => 'OTP'
                ]);
            }
            $status = $service->verify($data->mobile)->updateMobile();
        } else {
            $status = $service->updateInfo();
        }

        return $status
            ? successResponse(null)
            : failedResponse(trans('failed-messages.profile_update_failed'), FailedResponseCode::PROFILE_UPDATE_FAILED);

    }
}
