<?php

namespace App\Http\Controllers\User\Profile;

use App\Http\Controllers\Controller;
use App\Http\Resources\User\PurchaseHistoryResource;
use App\Http\Resources\User\PurchaseProductResource;
use App\Models\Order;
use App\Models\OrderProduct;

class PurchaseHistoryController extends Controller
{
    public function index()
    {
        $user = auth()->user();
        $user->load(['orders' => fn($q) => $q->with(['orderProductLanguages', 'currency'])->withSum('orderProducts as total_price', 'total_price')]);
        return successResponse([
            'purchases_history' => PurchaseHistoryResource::collection($user->orders)
        ]);
    }

    public function show(Order $order)
    {
        abort_if($order->user_id !== auth()->id(), 404, 'Not Found');

        $order->load(['orderProducts', 'currency']);
        $order->loadSum('orderProducts as total_price', 'total_price');

        $orderProducts = OrderProduct::query()
            ->with('order.currency')
            ->whereHas('order', fn($q) => $q->where('order_id', $order->id))
            ->get();

        return successResponse([
            'purchase_info' => new PurchaseHistoryResource($order),
            'products' => PurchaseProductResource::collection($orderProducts)
        ]);
    }
}
