<?php

namespace App\Http\Controllers\User;

use App\Helper\FailedResponseCode;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

class ReadingGoalController extends Controller
{
    public function store(Request $request)
    {
        $request->validate([
            'minute' => ['required', 'integer', 'min:1', 'max:60'],
            'second' => ['required', 'integer', 'min:0', 'max:59'],
        ]);

        $seconds = floor($request->minute * 60) + $request->second;

        $result = auth()->user()->readingGoals()->updateOrCreate([
            'read_at' => now()->toDateString()
        ], [
            'goal_time' => $seconds,
            'read_at' => now()->toDateString()
        ]);

        if (!$result) {
            return failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::READING_GOAL_FAILED);
        }

        return successResponse([
            'minute' => $request->minute,
            'second' => $request->second,
            'seconds' => $seconds,
            'seconds_format' => convertSecondToDHMS($seconds)
        ]);
    }

    public function destroy()
    {
        $deleted = auth()->user()->readingGoal()->delete();
        return $deleted
            ? successResponse(null)
            : failedResponse(trans('failed-messages.failed_operation'), FailedResponseCode::DELEATE_READING_GOAL_FAILED);
    }
}
