<?php

namespace App\Http\Controllers;

use App\Helper\Enum;
use App\Helper\FailedResponseCode;
use App\Http\Requests\UserSettingRequest;
use App\Models\UserSetting;

class UserSettingController extends Controller
{
    public function index()
    {
        $user = auth()->user();

        $settingsKeys = match ($user->role) {
            Enum::USER => UserSetting::USER_SETTINGS,
            Enum::MARKETER => UserSetting::MARKETER_SETTINGS,
            Enum::PUBLISHER => UserSetting::PUBLISHER_SETTINGS,
        };

        $user->load(['settings' => fn($q) => $q->whereIn('key', $settingsKeys)]);

        $settings = [];

        foreach ($user->settings as $setting) {
            $settings[$setting->key] = (bool)$setting->value;
        }

        return successResponse($settings);
    }

    public function update(UserSettingRequest $request)
    {
        $user = auth()->user();
        $userSettings = $request->validated();

        $user->load(['settings' => fn($q) => $q->whereIn('key', array_keys($userSettings))]);

        $success = true;

        foreach ($userSettings as $settingKey => $settingValue) {

            $setting = $user->settings->where('key', $settingKey)->first();

            if ($setting && $setting->value == $settingValue) {
                continue;
            }

            $status = !!$user->settings()->updateOrCreate(['key' => $settingKey, 'user_id' => $user->id], ['value' => $settingValue]);
            if (!$status)
                $success = false;
        }

        return $success
            ? successResponse(null)
            : failedResponse(trans('failed-messages.settings_update_failed'), FailedResponseCode::SETTINGS_UPDATE_FAILED);
    }
}
