<?php

namespace App\Http\Requests\Admin;

use App\Helper\Enum;
use App\Models\Product;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class BannerRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $rules = [
            'product_id' => ['nullable', 'numeric', 'exists:products,id'],
            'type' => ['required', 'string', Rule::in(Product::ELECTRONIC_BOOK, Product::AUDIO_BOOK, Product::MAGAZINE, Product::PODCAST)],
            'status' => ['required', 'string', Rule::in(Enum::STATUS_ACTIVE, Enum::STATUS_INACTIVE)],
            'translates' => ['required', 'array']
        ];

        foreach (app('languages') as $language) {
            $rules["translates.{$language->locale}.banner"] = ['required', 'string'];
            $rules["translates.{$language->locale}.mobile_banner"] = ['required', 'string'];
        }

        return $rules;
    }
}
