<?php

namespace App\Http\Requests\Admin;

use App\Models\Currency;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class DiscountRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $rules = [
            'code' => ['required', 'string', $this->route('discount') ? Rule::unique('discounts','code')->ignore($this->route('discount')) : 'unique:discounts'],
            'max_usage' => ['nullable', 'integer', 'min:0'],
            'started_at' => ['required', 'date'],
            'ended_at' => ['required', 'date'],
            'assigned_users' => ['nullable', 'array'],
            'assigned_users.*' => ['required', 'numeric', 'exists:users,id'],
        ];

        foreach (app('languages') as $language) {
            $rules["translates.{$language->locale}.title"] = ['required', 'string'];
            $rules["translates.{$language->locale}.description"] = ['required', 'string'];
        }

        foreach (Currency::all() as $currency) {
            $rules["prices.{$currency->currency}"] = ['required', 'numeric', 'min:0', 'max:90'];
        }

        return $rules;
    }
}
