<?php

namespace App\Http\Requests\Admin;

use App\Helper\Enum;
use App\Models\Country;
use App\Rules\IsMobileRule;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Facades\Route;
use Illuminate\Validation\Rule;

class MarketerRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $country = Country::query()->where('phone_code', $this->country_code)->first();

        if (Route::currentRouteName() === 'api.admin.marketers.store') {
            return [
                'first_name' => ['required', 'string', 'min:3', 'max:60'],
                'last_name' => ['required', 'string', 'min:3', 'max:60'],
                'email' => ['required', 'email', Rule::unique('users')->where('role', Enum::MARKETER)],
                'username' => ['required', 'string', Rule::unique('users')->where('role', Enum::MARKETER)],
                'password' => ['nullable', 'string', 'min:8', 'max:20', 'confirmed'],
                'country_code' => [Rule::requiredIf(!!request('mobile')), 'numeric', 'exists:countries,phone_code'],
                'mobile' => [Rule::requiredIf(!!request('country_code')), 'numeric', new IsMobileRule(), "phone:$country?->iso", Rule::unique('users')->where('role', Enum::MARKETER)],
                'gender' => ['required', 'string', Rule::in([Enum::GENDER_MALE, Enum::GENDER_FEMALE])],
                'status' => ['required', 'string', Rule::in([Enum::STATUS_ACTIVE, Enum::STATUS_PENDING, Enum::STATUS_INACTIVE])],
//                'profit' => ['required', 'integer', 'min:0', 'max:100'],
                'documents' => ['required', 'array', 'min:1'],
                'documents.*' => ['required', 'string']
            ];
        }

        $marketer = $this->route('user');
        return [
            'first_name' => ['required', 'string', 'min:3', 'max:60'],
            'last_name' => ['required', 'string', 'min:3', 'max:60'],
            'email' => ['required', 'email', Rule::unique('users')->where('role', Enum::USER)->ignore($marketer)],
            'username' => ['required', 'string', Rule::unique('users')->where('role', Enum::MARKETER)->ignore($marketer)],
            'password' => ['nullable', 'string', 'min:8', 'max:20', 'confirmed'],
            'country_code' => [$marketer->country_code ? 'required' : 'nullable', 'numeric', 'exists:countries,phone_code'],
            'mobile' => [$marketer->mobile ? 'required' : 'nullable', 'numeric', new IsMobileRule(), "phone:$country?->iso", Rule::unique('users')->where('role', Enum::USER)->ignore($marketer)],
            'gender' => ['required', 'string', Rule::in([Enum::GENDER_MALE, Enum::GENDER_FEMALE])],
            'status' => ['required', 'string', Rule::in([Enum::STATUS_ACTIVE, Enum::STATUS_PENDING, Enum::STATUS_INACTIVE])],
//            'profit' => ['required', 'numeric', 'min:0', 'max:90'],
            'documents' => ['required', 'array', 'min:1'],
            'documents.*' => ['required', 'string']
        ];
    }
}
