<?php

namespace App\Http\Requests\Admin;

use App\Helper\Enum;
use App\Models\Country;
use App\Models\User;
use App\Rules\IsMobileRule;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Facades\Route;
use Illuminate\Validation\Rule;

class UserRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $country = Country::query()->where('phone_code', $this->country_code)->first();

        if (Route::currentRouteName() === 'api.admin.users.store') {

            return [
                'first_name' => ['required', 'string', 'min:3', 'max:60'],
                'last_name' => ['required', 'string', 'min:3', 'max:60'],
                'birth_date' => ['required', 'date'],
                'email' => ['required', 'email', Rule::unique('users')->where('role', Enum::USER)],
                'password' => ['required', 'string', 'min:8', 'max:20', 'confirmed'],
                'country_code' => ['required', 'numeric', 'exists:countries,phone_code'],
                'mobile' => ['required', 'numeric', new IsMobileRule(), "phone:$country?->iso", Rule::unique('users')->where('role', Enum::USER)],
                'gender' => ['required', 'string', Rule::in([Enum::GENDER_MALE, Enum::GENDER_FEMALE])],
                'status' => ['required', 'string', Rule::in([Enum::STATUS_ACTIVE, Enum::STATUS_INACTIVE])],
            ];
        }


        return [
            'first_name' => ['required', 'string', 'min:3', 'max:60'],
            'last_name' => ['required', 'string', 'min:3', 'max:60'],
            'birth_date' => ['required', 'date'],
            'email' => ['required', 'email', Rule::unique('users')->where('role', Enum::USER)->ignore($this->route('user'))],
            'password' => ['nullable', 'string', 'min:8', 'max:20', 'confirmed'],
            'country_code' => ['required', 'numeric', 'exists:countries,phone_code'],
            'mobile' => ['required', 'numeric', new IsMobileRule(), "phone:$country?->iso", Rule::unique('users')->where('role', Enum::USER)->ignore($this->route('user'))],
            'gender' => ['required', 'string', Rule::in([Enum::GENDER_MALE, Enum::GENDER_FEMALE])],
            'status' => ['required', 'string', Rule::in([Enum::STATUS_ACTIVE, Enum::STATUS_INACTIVE])],
        ];
    }
}
