<?php

namespace App\Http\Requests;

use App\Helper\Enum;
use App\Models\Product;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;

class AllReadingReportRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'reading_items' => ['required', 'array', 'min:1'],
            'reading_items.*.id' => ['required', 'numeric', Rule::exists('products')->where('status', Enum::STATUS_ACTIVE)],
            'reading_items.*.product_type' => ['required', 'string', Rule::in([Product::ELECTRONIC_BOOK, Product::AUDIO_BOOK, Product::MAGAZINE, Product::PODCAST])],
            'reading_items.*.product_lang' => ['required', 'string', 'exists:languages,locale'],
            'reading_items.*.time' => ['required', 'integer']
        ];
    }

    public function prepareForValidation()
    {
        $items = [];
        if (isset($this->reading_items) && is_array($this->reading_items)) {
            foreach ($this->reading_items as $item) {
                $items[] = [
                    'id' => $item['id'],
                    'product_type' => Str::upper($item['product_type']),
                    'product_lang' => Str::lower($item['product_lang']),
                    'time' => $item['time'],
                ];
            }
        }

        $this->merge([
            'reading_items' => $items
        ]);
    }
}
