<?php

namespace App\Http\Requests\Auth;

use App\Helper\Enum;
use App\Models\Country;
use App\Rules\IsMobileRule;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;

class OTPRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $rules = [];

        if (Route::currentRouteName() === 'auth.otp.verify') {
            $rules['otp'] = ['required', 'numeric'];
        }

        if ($this?->mobile && $this?->country_code) {
            $country = Country::query()->where('phone_code', $this->country_code)->first();

            $rules['country_code'] = ['required', 'numeric', 'exists:countries,phone_code'];
            $rules['mobile'] = ['required', 'numeric', new IsMobileRule(), "phone:$country?->iso"];
        } else {
            $rules['email'] = ['required', 'email'];
        }

        return $rules;
    }
}
