<?php

namespace App\Http\Requests;

use App\Models\ContactUs;
use App\Models\Country;
use App\Rules\IsMobileRule;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;

class ContactUsRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        if ($user = auth()->user())
            return $user->tokenCan('user-access');

        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $country = Country::query()->where('phone_code', $this->country_code)->first();

        return [
            'os' => ['required', 'string', Rule::in(ContactUs::OS_LIST)],
            'title' => ['required', 'string', 'min:3', 'max:200'],
            'problem' => ['required', 'string', 'min:3', 'max:200'],
            'description' => ['required', 'string'],
            'country_code' => ['required', 'numeric', 'exists:countries,phone_code'],
            'mobile' => ['required', 'numeric', new IsMobileRule(), "phone:$country?->iso"],
            'email' => ['required', 'email'],
            'file' => ['nullable', 'file', 'mimes:pdf,epub,mp3,jpeg,jpg,png', 'max:10240']
        ];
    }

    protected function prepareForValidation()
    {
        $this->merge([
            'os' => Str::upper($this->os)
        ]);
    }
}
