<?php

namespace App\Http\Requests\Marketer;

use App\Helper\Enum;
use App\Models\Country;
use App\Rules\FileExistRule;
use App\Rules\IsMobileRule;
use App\Rules\UniqueMobileRule;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Jenssegers\Agent\Agent;

class RegisterRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $country = Country::query()->where('phone_code', $this->country_code)->first();

        $rules = [
            'first_name' => ['required', 'string'],
            'last_name' => ['required', 'string'],
            'national_code' => ['required', 'numeric'],
            'gender' => ['required', 'string', 'in:male,female'],
            'country_code' => ['required', 'numeric', 'exists:countries,phone_code'],
            'mobile' => ['required', 'numeric', new IsMobileRule(), "phone:$country?->iso", Rule::unique('users')->where(fn($q) => $q->where('mobile', 'LIKE', $this->mobile)->where('country_code', $this->country_code)->where('role', Enum::MARKETER))],
            'otp' => ['required', 'numeric'],
            'email' => ['required', 'email', Rule::unique('users')->where('role', Enum::MARKETER)],
            'referral' => ['nullable', 'string'],
            'documents' => ['required', 'array', 'max:5', new FileExistRule()],
        ];

        return combineApplicationAgent($rules);
    }
}
