<?php

namespace App\Http\Requests;

use App\Helper\Enum;
use App\Models\Product;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;

class ProductFilterRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $rules = [
            'title' => ['nullable', 'string'],
            'category' => is_numeric(request('category', '')) ? ['nullable', 'numeric', 'exists:categories,id'] : ['nullable', 'string', 'exists:category_languages,slug'],
            'genre' => ['nullable', 'numeric', 'exists:genre_languages,genre_id'],
            'sort_by' => ['nullable', 'string'],
        ];

        if (is_array(request("collaborator"))) {
            $rules['collaborator'] = ['nullable', 'array'];
            $rules['collaborator.*'] = ['required', 'numeric'];
        }

        if (is_array(request("publisher"))) {
            $rules['publisher'] = ['nullable', 'array'];
            $rules['publisher.*'] = ['required', 'numeric', Rule::exists('users', 'id')->where('role', Enum::PUBLISHER)];
        }

        if (is_array(request("product_type"))) {
            $rules['product_type'] = ['nullable', 'array'];
            $rules['product_type.*'] = ['required', 'string', Rule::in([Product::ELECTRONIC_BOOK, Product::AUDIO_BOOK, Product::PODCAST, Product::MAGAZINE])];
        }

        return $rules;
    }

    public function prepareForValidation()
    {
        $productTypes = $this->product_type ?? [];
        if (is_array($productTypes)) {
            $newProduct = [];
            foreach ($productTypes as $type) {
                $newProduct[] = Str::upper($type);
            }
        } else {
            $newProduct = [Str::upper($productTypes)];
        }

        $this->merge([
            'product_type' => $newProduct,
        ]);
    }
}
