<?php

namespace App\Http\Requests\Publisher;

use App\Models\Product;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;

class ProductFileRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules(): array
    {
        $rule = [
            'product_type' => ['required', 'string', Rule::in([Product::ELECTRONIC_BOOK, Product::AUDIO_BOOK, Product::PODCAST, Product::MAGAZINE])],
            'product_file_type' => ['required', 'string', Rule::in([Product::DEMO_FILE, Product::COVER_FILE, Product::MAIN_FILE])],
        ];

        $this->validate($rule);

        if ($this->product_file_type === Product::COVER_FILE) {
            $rule['product_file'] = ['required', 'file', 'mimes:jpeg,jpg,png'];

        } else {
            $rule['product_file'] = match ($this->product_type) {
                Product::PODCAST, Product::AUDIO_BOOK => ['required', 'file', 'mimes:mp3'],
                Product::ELECTRONIC_BOOK => ['required', 'file', 'mimes:epub,pdf,mp3'],
                Product::MAGAZINE => ['required', 'file', 'mimes:epub,pdf']
            };
        }

        return $rule;
    }

    protected function prepareForValidation()
    {
        $this->merge([
            'product_type' => Str::upper($this->product_type),
            'product_file_type' => Str::upper($this->product_file_type),
        ]);
    }
}
