<?php

namespace App\Http\Requests\Publisher;

use App\Helper\Enum;
use App\Models\Country;
use App\Models\User;
use App\Rules\FileExistRule;
use App\Rules\IsMobileRule;
use App\Rules\IsPhoneRule;
use App\Rules\UniqueMobileRule;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class ProfileRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $user = auth()->user();
        $user->load('publisherProfile');

//        if (($this?->mobile && $this?->country_code) && ($this->mobile !== $user->mobile || $this->country_code !== $user->country_code)) {
//            $country = Country::query()->where('phone_code', $this->country_code)->first();
//            return [
//                'country_code' => ['required', 'numeric', 'exists:countries,phone_code'],
//                'mobile' => ['required', 'numeric', new IsMobileRule(), "phone:$country?->iso", Rule::unique('users')->where(fn($q) => $q->where('mobile', 'LIKE', $this->mobile)->where('country_code', $this->country_code)->where('role', Enum::PUBLISHER))->ignore($user)],
//                'otp' => ['required', 'numeric']
//            ];
//        }

        return [
            'first_name' => ['required', 'string'],
            'last_name' => ['required', 'string'],
            'national_code' => [$user->national_code ? 'required' : 'nullable', 'numeric'],
            'gender' => ['required', 'string', 'in:male,female'],
            'phone' => ['nullable', 'numeric', new IsPhoneRule(),$user->publisherProfile ?  Rule::unique('publisher_profiles')->ignore($user->publisherProfile->id) : Rule::unique('publisher_profiles')],
            'publisher_name' => ['required', 'string', 'max:100'],
            'publisher_description' => ['nullable', 'string'],
            'publisher_email' => ['nullable', 'email',$user->publisherProfile ? Rule::unique('publisher_profiles')->ignore($user->publisherProfile->id) : Rule::unique('publisher_profiles')],
            'publisher_code' => ['nullable', 'numeric'],
            'publisher_address' => ['nullable', 'string'],
            'logo' => ['nullable', 'image'],
            'post_box' => ['nullable', 'numeric'],
            'postal_code' => ['nullable', 'numeric'],
        ];
    }
}
