<?php

namespace App\Http\Requests\User;

use App\Helper\Enum;
use App\Models\Product;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;

class AllReaderPercentRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'reading_percents' => ['required', 'array', 'min:1'],
            'reading_percents.*.id' => ['required', 'numeric', Rule::exists('products')->where('status', Enum::STATUS_ACTIVE)],
            'reading_percents.*.product_type' => ['required', 'string', Rule::in([Product::ELECTRONIC_BOOK, Product::AUDIO_BOOK, Product::MAGAZINE, Product::PODCAST])],
            'reading_percents.*.product_lang' => ['required', 'string', 'exists:languages,locale'],
            'reading_percents.*.value' => ['required', 'numeric'],
            'reading_percents.*.location' => ['required', 'string']
        ];
    }

    protected function prepareForValidation()
    {
        $items = [];
        if (isset($this->reading_percents) && is_array($this->reading_percents)) {
            foreach ($this->reading_percents as $item) {
                $items[] = [
                    'id' => $item['id'],
                    'product_type' => Str::upper($item['product_type']),
                    'product_lang' => Str::lower($item['product_lang']),
                    'value' => $item['value'],
                    'location' => $item['location']
                ];
            }
        }

        $this->merge([
            'reading_percents' => $items
        ]);
    }
}
