<?php

namespace App\Http\Requests\User\Auth;

use App\Models\Country;
use App\Models\User;
use App\Rules\IsMobileRule;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Jenssegers\Agent\Agent;

class AuthenticateRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        if ($this?->mobile && $this?->country_code) {
            $country = Country::query()->where('phone_code', $this->country_code)->first();

            $rules = [
                'country_code' => ['required', 'numeric', 'exists:countries,phone_code'],
                'mobile' => ['required', 'numeric', new IsMobileRule(), "phone:$country?->iso"],
                'otp' => ['required', 'numeric'],
                'referral' => ['nullable', 'string']
            ];
        } else {
            $rules = [
                'email' => ['required', 'email'],
                'password' => ['required', 'string', 'min:8', 'max:20'],
                'otp' => ['nullable', 'numeric'],
//                'referral' => ['nullable', 'string']
            ];
        }

        return combineApplicationAgent($rules);
    }
}
