<?php

namespace App\Http\Requests\User;

use App\Helper\Enum;
use App\Models\Country;
use App\Models\Marketer;
use App\Models\User;
use App\Rules\IsMobileRule;
use App\Rules\UniqueMobileRule;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class ProfileRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $user = auth()->user();

        if (($this?->mobile && $this?->country_code) && ($this->mobile != $user->mobile || $this->country_code != $user->country_code)) {
            $country = Country::query()->where('phone_code', $this->country_code)->first();
            return [
                'country_code' => ['required', 'numeric', 'exists:countries,phone_code'],
                'mobile' => ['required', 'numeric', new IsMobileRule(), "phone:$country?->iso", Rule::unique('users')->where(fn($q) => $q->where('mobile', 'LIKE', $this->mobile)->where('country_code', $this->country_code)->where('role', Enum::USER))->ignore($user)],
                'otp' => ['nullable', 'numeric']
            ];
        }

        if ($this?->email && $this->email !== $user->email) {
            return [
                'email' => ['required', 'email', Rule::unique('users', 'email')->where('role', Enum::USER)->ignore($user)],
                'otp' => ['nullable', 'numeric']
            ];
        }

        return [
            'first_name' => ['required', 'string', 'max:100'],
            'last_name' => ['required', 'string', 'max:100'],
            'birth_date' => ['required', 'date'],
            'gender' => ['required', 'string', 'in:male,female']
        ];
    }
}
