<?php

namespace App\Http\Requests;

use App\Helper\Enum;
use App\Models\UserSetting;
use Illuminate\Foundation\Http\FormRequest;
use JetBrains\PhpStorm\ArrayShape;
use JetBrains\PhpStorm\Deprecated;

class UserSettingRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        $user = auth()->user();

        return match ($user->role) {
            Enum::USER => $this->getUserSettingRules(),
            Enum::MARKETER => $this->getMarketerSettingRules(),
            Enum::PUBLISHER => $this->getPublisherSettingRules(),
            default => []
        };
    }

    protected function getUserSettingRules(): array
    {
        return [
            'receive_email' => ['required', 'numeric', 'in:0,1']
        ];
    }

    protected function getMarketerSettingRules(): array
    {
        return [
            'receive_email' => ['required', 'numeric', 'in:0,1']
        ];
    }

    protected function getPublisherSettingRules(): array
    {
        return [
            'receive_submit_email' => ['nullable', 'numeric', 'in:0,1'],
            'receive_change_email' => ['nullable', 'numeric', 'in:0,1'],
            'receive_change_product_email' => ['nullable', 'numeric', 'in:0,1'],
            'receive_user_comment_email' => ['nullable', 'numeric', 'in:0,1']
        ];
    }
}
