<?php

namespace App\Http\Resources\Admin;

use App\Models\Admin;
use App\Models\User;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Str;

class CommentResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        return [
            'id' => $this->id,
            'comment_id' => $this->comment_id,
            'title' => $this->title,
            'comment' => $this->comment,
            'user' => $this->when($this->commentable_type === User::class, new UserResource($this->commentable)),
            'admin' => $this->when($this->commentable_type === Admin::class, new AdminResource($this->commentable)),
            'product' => $this->whenLoaded('product', fn() => [
                'id' => $this->product->id,
                'title' => $this->product->translate?->title,
            ]),
            'status' => Str::lower($this->status),
            'likes_count' => $this->likes_count,
            'dislikes_count' => $this->dislikes_count,
            'replies' => $this->whenLoaded('replies', fn() => static::collection($this->replies)),
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ];
    }

    protected function getName()
    {
        switch ($this->commentable_type) {
            case User::class:
                return trim($this->commentable->full_name) === "" ? trans('translates.user') : $this->commentable->full_name;
            case Admin::class:
                return $this->commentable->name . ' (' . trans('translates.admin') . ')';
            default:
                return '';
        }
    }
}
