<?php

namespace App\Http\Resources\Admin;

use Illuminate\Contracts\Support\Arrayable;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use JsonSerializable;

class DiscountResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array|Arrayable|JsonSerializable
     */
    public function toArray($request)
    {
        $translates = [];
        foreach ($this->translates as $translate) {
            $translates[$translate->language_locale] = [
                'title' => $translate->title,
                'description' => $translate->description,
            ];
        }

        $prices = [];
        foreach ($this->prices as $price) {
            $prices[$price->currency_code] = $price->percent;
        }

        return [
            'id' => $this->id,
            'code' => $this->code,
            'max_usage' => $this->max_usage,
            'started_at' => $this->started_at,
            'ended_at' => $this->ended_at,
            'used_users_count' => $this->used_users_count ?? null,
            'assigned_users_count' => $this->assigned_users_count ?? null,
            'assigned_users' => UserResource::collection($this->whenLoaded('assignedUsers')),
            'title' => $this->translate->title,
            'description' => $this->translate->description,
            'translates' => $translates,
            'prices' => $prices
        ];
    }
}
