<?php

namespace App\Http\Resources\Admin;

use App\Models\Setting;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Str;

class MarketerResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        $marketerProfit = Cache::rememberForever('marketer_profit', fn() => Setting::valueOf([Setting::MARKETER_PROFIT])->first()?->value);

        return [
            'id' => $this->id,
            'first_name' => $this->first_name,
            'last_name' => $this->last_name,
            'email' => $this->email,
            'email_verified_at' => $this->email_verified_at,
            'username' => $this->username,
            'mobile' => $this->mobile,
            'country_code' => $this->country_code,
            'mobile_verified_at' => $this->mobile_verified_at,
            'register_type' => Str::lower($this->register_type),
            'gender' => Str::lower($this->gender),
            'referral_code' => $this->referral_code,
            'documents' => DocumentResource::collection($this->whenLoaded('documents')),
            'min_profit' => $this->min_profit ?? $marketerProfit,
            'max_profit' => $this->max_profit ?? $marketerProfit,
            'status' => Str::lower($this->status),
            'created_at' => $this->created_at
        ];
    }
}
