<?php

namespace App\Http\Resources\Admin;

use App\Http\Resources\Publisher\CollaboratorResource;
use App\Http\Resources\ShowProductReviewPartsResource;
use Illuminate\Contracts\Support\Arrayable;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Str;
use JsonSerializable;

class ProductResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array|Arrayable|JsonSerializable
     */
    public function toArray($request)
    {
        $translates = [];
        foreach ($this->translates as $translate) {
            $prices = [];
            foreach ($translate->prices as $price) {
                $prices[$price->currency_code] = [
                    'id' => $price->id,
                    'price' => $price->price,
                    'discount_percent' => $price->discount_percent,
                    'discount_started_at' => $price->discount_started_at,
                    'discount_ended_at' => $price->discount_ended_at,
                    'created_at' => $price->created_at,
                ];
            }
            $translates[$translate->language_locale] = [
                'id' => $translate->id,
                'title' => $translate->title,
                'description' => $translate->description,
                'collection' => $translate->collection?->translate?->title,
                'seasons' => $translate->seasons,
                'volume' => $translate->volume,
                'pages' => $translate->pages,
                'cover_url' => $translate->cover_url,
                'purchase_type' => Str::lower($translate->purchase_type),
                'published_at' => $translate->published_at,
                'has_special_discount' => $translate->has_special_discount,
                'created_at' => $translate->created_at,
                'collaborators' => CollaboratorResource::collection($translate->collaborators),
                'reviews' => $translate->review ? ShowProductReviewPartsResource::collection($translate->review->parts) : [],
                'files' => ProductFileResource::collection($translate->files),
                'prices' => $prices
            ];
        }

        return [
            'id' => $this->id,
            'title' => $this->translate?->title,
            'publisher' => [
                'id' => $this->publisher->id,
                'name' => $this->publisher->publisherProfile?->publisher_name,
            ],
            'type' => Str::lower($this->type),
            'secondary_type' => Str::lower($this->secondary_type),
            'category' => $this->category?->translate->title,
            'sub_category' => $this->subCategory?->translate->title,
            'filter_category' => $this->filterCategory?->translate->title,
            'genre' => $this->genre?->translate?->title,
            'limited_countries' => ProductCountryResource::collection($this->whenLoaded('limitedCountries')),
            'translates' => $translates,
            'status' => Str::lower($this->status),
            'created_at' => $this->created_at
        ];
    }
}
