<?php

namespace App\Http\Resources\Admin;

use App\Models\Category;
use App\Models\Collaborator;
use App\Models\Genre;
use App\Models\User;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Str;

class ProductSectionResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        $translates = [];
        foreach ($this->translates as $translate) {
            $translates[$translate->language_locale] = [
                'title' => $translate->title
            ];
        }

        return [
            'id' => $this->id,
            'title' => $this->translate->title,
            'translates' => $translates,
            'filter_type' => Str::lower(Str::afterLast($this->filterable_type,'\\')),
            'filter' => $this->getFilterData()
        ];
    }

    protected function getFilterData()
    {
        switch ($this->filterable_type) {
            case Category::class:
                return [
                    'id' => $this->filterable->id,
                    'title' => $this->filterable->translate->title,
                ];
            case Collaborator::class:
                return [
                    'id' => $this->filterable->id,
                    'name' => $this->filterable->translate->name,
                ];
            case User::class:
                $this->filterable->load('publisherProfile');
                return [
                    'id' => $this->filterable->id,
                    'country_code' => $this->filterable->country_code,
                    'mobile' => $this->filterable->mobile,
                    'email' => $this->filterable->email,
                    'fullname' => $this->filterable->fullname,
                    'publisher_name' => $this->filterable->publisherProfile->publisher_name,
                ];
            case Genre::class:
                return [
                    'id' => $this->filterable->id,
                    'name' => $this->filterable->translate->name,
                ];
        }
    }
}
