<?php

namespace App\Http\Resources\Admin;

use App\Models\Setting;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Str;

class PublisherResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        return [
            'id' => $this->id,
            'first_name' => $this->first_name,
            'last_name' => $this->last_name,
            'email' => $this->email,
            'email_verified_at' => $this->email_verified_at,
            'username' => $this->username,
            'mobile' => $this->mobile,
            'country_code' => $this->country_code,
            'mobile_verified_at' => $this->mobile_verified_at,
            'register_type' => Str::lower($this->register_type),
            'gender' => Str::lower($this->gender),
            'referral_code' => $this->referral_code,
            'documents' => DocumentResource::collection($this->whenLoaded('documents')),
            'profile' => new PublisherProfileResource($this->whenLoaded('publisherProfile')),
            'profit' => $this->profit->publisher_profit ?? 0,
            'marketer_profit' => $this->profit->marketer_profit ?? 0,
            'site_profit' => $this->profit->site_profit ?? 0,
            'marketer' => $this->whenLoaded('inviter', function () {
                return [
                    'id' => $this->inviter->id,
                    'full_name' => trim($this->profit?->marketer->full_name) === "" ? trans('translates.user') : $this->profit?->marketer->full_name,
                    'referral_code' => $this->inviter->referral_code,
                    'status' => Str::lower($this->inviter->status),
                ];
            }),
            'status' => Str::lower($this->status),
            'created_at' => $this->created_at
        ];
    }
}
