<?php

namespace App\Http\Resources\Admin;

use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class SliderResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        $translates = [];
        foreach ($this->translates as $translate) {
            $translates[$translate->language_locale] = [
                'slide' => $translate->slide,
                'slide_url' => Storage::url($translate->slide),
                'mobile_slide' => $translate->mobile_slide,
                'mobile_slide_url' => Storage::url($translate->mobile_slide),
            ];
        }

        return [
            'id' => $this->id,
            'translates' => $translates,
            'link' => $this->link,
            'product' => $this->whenLoaded('product', fn() => [
                'id' => $this->product?->id,
                'title' => $this->product?->translate?->title,
                'slug' => $this->product?->translate?->slug,
                'type' => Str::lower($this->type),
                'secondary_type' => Str::lower($this->secondary_type),
                'status' => Str::lower($this->status)
            ]),
            'slide_url' => Storage::url($this->translate->slide),
            'mobile_slide_url' => Storage::url($this->translate->mobile_slide),
            'status' => Str::lower($this->status)
        ];
    }
}
