<?php

namespace App\Http\Resources;

use App\Helper\Enum;
use App\Models\Collaborator;
use App\Models\Product;
use App\Services\Product\ProductViewService;
use Illuminate\Contracts\Support\Arrayable;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Collection;
use Illuminate\Support\Str;
use JsonSerializable;

class ProductResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array|Arrayable|JsonSerializable
     */
    public function toArray($request)
    {
        $user = auth()->user();
        $alreadyPurchased = ProductViewService::alreadyPurchased($this->resource, $user, $this->translate);
        return [
            'id' => $this->id,
            'is_purchased' => $alreadyPurchased,
            'purchase_type' => Str::lower($this->translate->purchase_type),
            'type' => Str::lower($this->type),
            'secondary_type' => $this->when($this->secondary_type, $this->secondary_type ? Str::lower($this->secondary_type) : null),
            'pages' => $this->translate->pages,
            'status' => Str::lower($this->status),
            'title' => $this->translate->title,
            'slug' => $this->translate->slug,
            'description' => $this->translate->description,
            'author' => $this->translate?->collaborators?->where('type', Collaborator::AUTHOR)->first()?->translate?->name,
            'translator' => $this->translate?->collaborators?->where('type', Collaborator::TRANSLATOR)->first()?->translate?->name,
            'speaker' => $this->translate?->collaborators?->where('type', Collaborator::SPEAKER)->first()?->translate?->name,
            'cover' => $this->translate->cover_url
        ];
    }
}
