<?php

namespace App\Http\Resources\Publisher;

use App\Http\Resources\ShowProductPriceResource;
use App\Models\Collaborator;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Str;

class OrderRecordResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        return [
            'id' => $this->locale_product->product_id,
            'order_number' => $this->order->order_number,
            'language' => $this->locale_product->language_locale,
            'title' => $this->locale_product->translate?->title,
            'order_type' => Str::lower($this->type),
            'slug' => $this->locale_product->translate?->slug,
            'prices' => [
                'currency' => $this->order->currency_code,
                'price' => number_format($this->price, $this->order->currency->floating_point ? 2 : 0),
                'discount_percent' => $this->discount,
                'total_price' => number_format($this->total_price, $this->order->currency->floating_point ? 2 : 0, '.', ''),
                'total_price_format' => $this->order->currency->translate->name . ' ' . number_format($this->total_price, $this->order->currency->floating_point ? 2 : 0),
            ],
            'paid_at' => $this->order?->paid_at?->format('Y/m/d - H:i'),
        ];
    }
}
