<?php

namespace App\Http\Resources;

use App\Models\Collaborator;
use App\Models\Product;
use App\Services\Product\ProductViewService;
use Illuminate\Contracts\Support\Arrayable;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Str;
use JsonSerializable;

class ShowPodcastResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array|Arrayable|JsonSerializable
     */
    public function toArray($request)
    {
        $this->user = auth()->user();

//        $demoFile_mp3 = $this->translate->files->where('type', Product::DEMO_FILE)->where('extension', 'mp3')->first();

        $mainFile_mp3 = $this->translate->files->where('type', Product::MAIN_FILE)->where('extension', 'mp3')->first();

        $alreadyPurchased = ProductViewService::alreadyPurchased($this->resource, $this->user, productType: Product::PODCAST);

        return [
            'id' => $this->id,
            'languages' => $this->supported_languages,
            'current_language' => $this->translate->language_locale,
            'is_purchased' => $alreadyPurchased,
            'is_bookmarked' => !!$this->user?->bookmarkedProducts()->where('products.id', $this->id)->first(),
            'in_cart' => ProductViewService::inCart($this->resource, $this->user, productType: Product::PODCAST),
            'title' => $this->translate->title,
            'slug' => $this->translate->slug,
            'description' => $this->translate->description,
            'type' => Str::lower($this->type),
            'secondary_type' => $this->when($this->secondary_type, Str::lower($this->secondary_type)),
            'share_url' => config('app.front_url') . "/products/{$this->translate->slug}",
            'episode' => $this->episode,
//            'seasons' => $this->translate->seasons,
//            'volume' => $this->translate->volume,
            'purchase_type' => Str::lower($this->translate->purchase_type),
            'published_at' => $this->translate->published_at?->toDateString(),
//            'pages' => $this->translate->pages,
            'cover' => $this->translate->cover_url,
            'mp3_size' => $mainFile_mp3 ? $mainFile_mp3->size . ' MB' : null,
            'mp3_duration' => $mainFile_mp3?->duration,
//            'demo_mp3_duration' => $demoFile_mp3?->duration,
            'category' => [
                'id' => $this->category->id,
                'title' => $this->category->translate->title,
                'slug' => $this->category->translate->slug,
            ],
            'sub_category' => [
                'id' => $this->subCategory->id,
                'title' => $this->subCategory->translate->title,
                'slug' => $this->subCategory->translate->slug,
            ],
            'filter_category' => [
                'id' => $this->filterCategory->id,
                'title' => $this->filterCategory->translate->title,
                'slug' => $this->filterCategory->translate->slug,
            ],
            'genre' => $this->genre ? [
                'id' => $this->genre->id,
                'title' => $this->genre->translate->title,
                'slug' => $this->genre->translate->slug,
            ] : null,
            'collection' => $this->translate?->collection ? [
                'id' => $this->translate->collection->id,
                'title' => $this->translate->collection->translate->title,
                'slug' => $this->translate->collection->translate->slug,
            ] : null,
//            'demo' => [
//                'mp3' => $demoFile_mp3 ? [
//                    'url' => $demoFile_mp3->url,
//                    'size' => $demoFile_mp3->size . ' MB'
//                ] : null,
//            ],
            'main' => $this->when(
                $this->translate->purchase_type === Product::FREE ||
                ($alreadyPurchased[$this->type === Product::AUDIO_BOOK || $this->secondary_type === Product::AUDIO_BOOK ? Str::lower(Product::AUDIO_BOOK) : Str::lower(Product::PODCAST)] ?? null)
                , $mainFile_mp3?->url),
//            'prices' => ShowProductPriceResource::collection($this->translate->prices)->resolve(),
            'authors' => ShowProductAuthorResource::collection($this->translate->collaborators->where('type', Collaborator::AUTHOR))->resolve(),
            'translators' => ShowProductTranslatorResource::collection($this->translate->collaborators->where('type', Collaborator::TRANSLATOR))->resolve(),
            'speakers' => ShowProductSpeakerResource::collection($this->translate->collaborators->where('type', Collaborator::SPEAKER))->resolve(),
        ];

    }
}
