<?php

namespace App\Http\Resources;

use App\Models\Admin;
use App\Models\User;
use Illuminate\Contracts\Support\Arrayable;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Str;
use JsonSerializable;

class ShowProductCommentResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array|Arrayable|JsonSerializable
     */
    public function toArray($request)
    {
        $vote = $this->votes->first();
        return [
            'id' => $this->id,
            'name' => $this->getFullName(),
            'role' => $this->getRole(),
            'title' => $this->title,
            'comment' => $this->comment,
            'likeCount' => $this->likes_count,
            'dislikeCount' => $this->dislikes_count,
            'time_age' => $this->created_at->diffForHumans(),
            'liked' => $vote && !!$vote->pivot->like,
            'disliked' => $vote && !!!$vote->pivot->like,
            'replies' => static::collection($this->replies)
        ];
    }

    protected function getFullName()
    {
        switch ($this->commentable_type) {
            case User::class:
                return trim($this->commentable->full_name) === "" ? trans('translates.user') : $this->commentable->full_name;
            case Admin::class:
                return $this->commentable->name . ' (' . trans('translates.admin') . ')';
            default:
                return '';
        }
    }

    protected function getRole()
    {
        switch ($this->commentable_type) {
            case User::class:
                return Str::lower($this->commentable->role);
            case Admin::class:
                return 'admin';
            default:
                return 'user';
        }
    }
}
