<?php

namespace App\Http\Resources;

use Illuminate\Http\Resources\Json\JsonResource;

class ShowProductPriceResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        $price = $discountPrice = $this->price;
        $discountPercent = $this->discount_percent ?? 0;

        if ($discountPercent > 0 && now() > $this->discount_started_at && now() < $this->discount_ended_at) {
            $discountPrice = $price - (($price * $discountPercent) / 100);
        }

        return [
            'id' => $this->id,
            'currency' => $this->currency_code,
            'currency_name' => $this->currency->translate->name,
            'price' => number_format($this->price, $this->currency->floating_point ? 2 : 0),
            'discount_percent' => $discountPercent,
            'total_price' => number_format($discountPrice, $this->currency->floating_point ? 2 : 0, '.', ''),
            'total_price_format' => $this->currency->translate->name . ' ' . number_format($discountPrice, $this->currency->floating_point ? 2 : 0),
            'discount_ended_at' => $discountPercent > 0 &&  $this->discount_ended_at? $this->discount_ended_at->toDateString() : null
        ];
    }
}
