<?php

namespace App\Http\Resources\User;

use App\Http\Resources\ShowProductPriceResource;
use App\Models\Collaborator;
use App\Models\Order;
use App\Models\Product;
use App\Services\Product\ProductViewService;
use Illuminate\Contracts\Support\Arrayable;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Str;
use JsonSerializable;

class LibraryResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array|Arrayable|JsonSerializable
     */
    public function toArray($request)
    {
        $user = auth()->user();
        $mainFile_epub = $this->productLanguage?->purchase_type === Product::FREE || $this->type === Product::ELECTRONIC_BOOK || $this->type === Product::MAGAZINE
            ? $this->productLanguage?->files->where('type', Product::MAIN_FILE)->where('extension', 'epub')->first()
            : null;

        $mainFile_pdf = $this->productLanguage?->purchase_type === Product::FREE || $this->type === Product::ELECTRONIC_BOOK || $this->type === Product::MAGAZINE
            ? $this->productLanguage?->files->where('type', Product::MAIN_FILE)->where('extension', 'pdf')->first()
            : null;

        $mainFile_mp3 = $this->productLanguage?->purchase_type === Product::FREE || $this->type === Product::AUDIO_BOOK || $this->type === Product::PODCAST
            ? $this->productLanguage?->files->where('type', Product::MAIN_FILE)->where('extension', 'mp3')->first()
            : null;

        //Todo: improve performance
        $reader = $user->readers()->where([
            'product_id' => $this->product_id,
            'product_language_id' => $this->product_language_id,
        ])->where(function ($q) {
            $q->where('type', $this->product->type)
                ->orWhere('type', $this->product->secondary_type);
        })->first();

        $alreadyPurchased = ProductViewService::alreadyPurchased($this->product, $user, $this->productLanguage);
        return [
            'id' => $this->product_id,
            'library_id' => $this->id,
            'is_purchased' => $alreadyPurchased,
            'language' => $this->productLanguage?->language_locale,
            'title' => $this->productLanguage?->title,
            'order_type' => Str::lower($this->type),
            'reader_percent' => $reader && $reader->total ? ($reader->last * 100) / $reader->total : 0,
            'slug' => $this->productLanguage?->slug,
            'epub_size' => $mainFile_epub ? $mainFile_epub->size . ' MB' : null,
            'mp3_size' => $mainFile_mp3 ? $mainFile_mp3->size . ' MB' : null,
            'mp3_duration' => $mainFile_mp3 ? $mainFile_mp3->duration : null,
            'mp3_duration_format' => $mainFile_mp3 ? convertSecondToDHMS($mainFile_mp3->duration) : null,
//            'prices' => $this->when($this->productLanguage->translate?->purchase_type === Product::PAID, [
//                'currency' => $this->order->currency_code,
//                'price' => number_format($this->price, $this->order->currency->floating_point ? 2 : 0),
//                'discount_percent' => $this->discount,
//                'total_price' => number_format($this->total_price, $this->order->currency->floating_point ? 2 : 0, '.', ''),
//                'total_price_format' => $this->order->currency->translate->name . ' ' . number_format($this->total_price, $this->order->currency->floating_point ? 2 : 0),
//            ]),
            'main' => [
                'epub' => (isset($alreadyPurchased['electronic_book']) || isset($alreadyPurchased['magazine'])) && $mainFile_epub
                    ? [
                        'url' => $mainFile_epub->url,
                        'size' => $mainFile_epub->size . ' MB'
                    ] : null,
                'pdf' => $mainFile_pdf ? [
                    'url' => $mainFile_pdf->url,
                    'size' => $mainFile_pdf->size . ' MB'
                ] : null,
                'mp3' => (isset($alreadyPurchased['podcast']) || isset($alreadyPurchased['audio_book'])) && $mainFile_mp3
                    ? [
                        'url' => $mainFile_mp3->url,
                        'size' => $mainFile_mp3->size . ' MB',
                        'duration' => $mainFile_mp3->duration,
                        'duration_format' => convertSecondToDHMS($mainFile_mp3->duration),
                    ] : null,
            ],
            'author' => $this->productLanguage?->collaborators?->where('type', Collaborator::AUTHOR)->first()?->translates->where('language_locale', $this->productLanguage->language_locale)?->first()?->name,
            'translator' => $this->productLanguage?->collaborators?->where('type', Collaborator::TRANSLATOR)->first()?->translates->where('language_locale', $this->productLanguage->language_locale)?->first()?->name,
            'speaker' => $this->productLanguage?->collaborators?->where('type', Collaborator::SPEAKER)->first()?->translates->where('language_locale', $this->productLanguage->language_locale)?->first()?->name,
            'cover' => $this->productLanguage?->cover_url
        ];
    }
}
