<?php

namespace App\Http\Resources\User;

use App\Http\Resources\ShowProductAuthorResource;
use App\Http\Resources\ShowProductPriceResource;
use App\Http\Resources\ShowProductSpeakerResource;
use App\Http\Resources\ShowProductTranslatorResource;
use App\Models\Collaborator;
use App\Models\Order;
use App\Models\Product;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Str;

class PurchaseProductResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        return [
            'id' => $this->locale_product->product_id,
            'language' => $this->locale_product->language_locale,
            'title' => $this->locale_product->translate?->title,
            'description' => $this->locale_product->translate?->description,
            'order_type' => Str::lower($this->type),
            'slug' => $this->locale_product->translate?->slug,
            'prices' => $this->order && $this->order->status === Order::PAID ? [
                'currency' => $this->order->currency_code,
                'price' => number_format($this->price, $this->order->currency->floating_point ? 2 : 0),
                'discount_percent' => $this->discount,
                'total_price' => number_format($this->total_price, $this->order->currency->floating_point ? 2 : 0, '.', ''),
                'total_price_format' => $this->order->currency->translate->name . ' ' . number_format($this->total_price, $this->order->currency->floating_point ? 2 : 0),
            ] : ShowProductPriceResource::collection($this->locale_product->translate?->prices),
            'author' => $this->locale_product?->translate->collaborators?->where('type', Collaborator::AUTHOR)->first()?->translates->where('language_locale', $this->locale_product->language_locale)?->first()?->name,
            'translator' => $this->locale_product?->translate->collaborators?->where('type', Collaborator::TRANSLATOR)->first()?->translates->where('language_locale', $this->locale_product->language_locale)?->first()?->name,
            'speaker' => $this->locale_product?->translate->collaborators?->where('type', Collaborator::SPEAKER)->first()?->translates->where('language_locale', $this->locale_product->language_locale)?->first()?->name,
            'cover' => $this->locale_product?->translate->cover_url
        ];
    }
}
