<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Passport\HasApiTokens;


class Admin extends Authenticatable
{
    use HasFactory, HasApiTokens, Notifiable;

    protected $guarded = ['id'];

    protected $hidden = [
        'password'
    ];

    protected $casts = [
        'last_activity_at' => 'datetime'
    ];

    public function role(): BelongsTo
    {
        return $this->belongsTo(Role::class);
    }

    public function hasPermission(Permission $permission)
    {
        $role = $this->role()->first();
        if (!$role) {
            return false;
        }
        $role->load(['permissions']);
        return $role->permissions->contains('key', $permission->key);
    }

    public function revokeAllTokens()
    {
        $this->load(['tokens' => fn($q) => $q->where('name', 'admin auth token')->where('revoked', false)]);

        foreach ($this->tokens as $token) {
            $token->revoke();
        }

        $this->unsetRelation('tokens');
    }

    public function comments()
    {
        return $this->morphMany(Comment::class, 'commentable');
    }
}
