<?php

namespace App\Models;

use App\Contracts\TranslateModel;
use App\Helper\Enum;
use Cviebrock\EloquentSluggable\Sluggable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Collaborator extends TranslateModel
{
    use HasFactory, SoftDeletes;

    const AUTHOR = 'AUTHOR';
    const TRANSLATOR = 'TRANSLATOR';
    const SPEAKER = 'SPEAKER';

    protected $guarded = ['id'];

    public function scopeAuthor($q)
    {
        return $q->where('type', static::AUTHOR);
    }

    public function scopeTranslator($q)
    {
        return $q->where('type', static::TRANSLATOR);
    }

    public function scopeSpeaker($q)
    {
        return $q->where('type', static::SPEAKER);
    }

    public function scopeActive($q)
    {
        return $q->where('status', Enum::STATUS_ACTIVE);
    }

    public function scopeActiveOrBelongsTo($q, $publisherId)
    {
        return $q->where(function ($q) use ($publisherId) {
            $q->where('status', Enum::STATUS_ACTIVE)
                ->orWhere('publisher_id', $publisherId);
        });
    }

    public function products()
    {
        return $this->belongsToMany(Product::class, 'product_collaborators');
    }

    public function productLanguages()
    {
        return $this->belongsToMany(ProductLanguage::class, 'product_collaborators');
    }
}
