<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Comment extends Model
{
    use HasFactory;

    const APPROVED = 'APPROVED';
    const PENDING = 'PENDING';
    const DISAPPROVED = 'DISAPPROVED';

    protected $guarded = ['id'];

    protected $withCount = [
        'likes',
        'dislikes'
    ];

    public function scopeApproved($q)
    {
        return $q->where('status', static::APPROVED);
    }

    public function commentable()
    {
        return $this->morphTo()->withTrashed();
    }

    public function product()
    {
        return $this->belongsTo(Product::class)->withTrashed();
    }

    public function replies()
    {
        return $this->hasMany(static::class);
    }

    public function parentComment()
    {
        return $this->belongsTo(static::class);
    }

    public function likes()
    {
        return $this->belongsToMany(User::class, 'comment_likes')->wherePivot('like', 1)->withTimestamps();
    }

    public function dislikes()
    {
        return $this->belongsToMany(User::class, 'comment_likes')->wherePivot('like', 0)->withTimestamps();
    }

    public function votes()
    {
        return $this->belongsToMany(User::class, 'comment_likes')->withTimestamps()->withPivot('like');
    }
}
