<?php

namespace App\Models;

use App\Contracts\TranslateModel;
use App\Helper\ReferralGenerator;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Discount extends TranslateModel
{
    use HasFactory, SoftDeletes;

    protected $guarded = ['id'];

    protected $casts = [
      'started_at'=>'date',
      'ended_at'=>'date',
    ];

    protected static function booted()
    {
        static::creating(function ($model) {
            if (!$model->code)
                $model->code = ReferralGenerator::generate(static::class, 'code', 5);
        });

        parent::booted();
    }

    public function prices()
    {
        return $this->hasMany(DiscountPrice::class);
    }

    public function usedUsers(): BelongsToMany
    {
        return $this->belongsToMany(User::class, 'used_discounts');
    }

    public function assignedUsers(): BelongsToMany
    {
        return $this->belongsToMany(User::class, 'assigned_discounts');
    }
}
