<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Library extends Model
{
    use HasFactory;

    protected $guarded = ['id'];

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function scopeMagazine($q)
    {
        return $q->where('type', Product::MAGAZINE);
    }

    public function scopePodcast($q)
    {
        return $q->where('type', Product::PODCAST);
    }

    public function scopeElectronicBook($q)
    {
        return $q->where('type', Product::ELECTRONIC_BOOK);
    }

    public function scopeAudioBook($q)
    {
        return $q->where('type', Product::AUDIO_BOOK);
    }

    public function scopeDataSummary($q, $userId)
    {
        return $q->with(['product'=>fn($q)=>$q->withTrashed()->active(), 'productLanguage' => function ($q) {
            $q->with(['collaborators', 'files'])->withTrashed();
        }])->where('user_id', $userId);
    }

    public function product()
    {
        return $this->belongsTo(Product::class);
    }

    public function productLanguage()
    {
        return $this->belongsTo(ProductLanguage::class);
    }
}
