<?php

namespace App\Models;

use App\Helper\ReferralGenerator;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Order extends Model
{
    use HasFactory, SoftDeletes;

    protected $guarded = ['id'];

    protected $casts = [
        'paid_at' => 'datetime'
    ];

    const NOT_PAID = 'NOT_PAID';
    const PAID = 'PAID';

    protected static function booted()
    {
        static::creating(function ($model) {
            $model->order_number = ReferralGenerator::generate(static::class, 'order_number', callback: fn() => random_int(10000000000, 99999999999));
        });
    }

    public function scopePaid($q)
    {
        return $q->where('status', static::PAID);
    }

    public function scopeNotPaid($q)
    {
        return $q->where('status', static::NOT_PAID);
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function products()
    {
        return $this->belongsToMany(Product::class, 'order_products');
    }

    public function orderProducts()
    {
        return $this->hasMany(OrderProduct::class);
    }

    public function orderProductLanguages()
    {
        return $this->belongsToMany(ProductLanguage::class, 'order_products')->withPivot(['type', 'language_locale', 'price', 'discount', 'total_price']);
    }

    public function transaction()
    {
        return $this->morphOne(Transaction::class, 'transactionable');
    }

    public function currency()
    {
        return $this->belongsTo(Currency::class, 'currency_code', 'currency');
    }
}
