<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class OrderProduct extends Model
{
    use HasFactory;

    protected $guarded = ['id'];

//    protected $appends = ['locale_product'];

    public function scopeOrderExists($q, $userId)
    {
        return $q->whereHas('order', fn($orderQuery) => $orderQuery->paid())
            ->where('user_id', $userId);
    }

    public function scopeElectronicBook($q)
    {
        return $q->where('type', Product::ELECTRONIC_BOOK);
    }

    public function scopeAudioBook($q)
    {
        return $q->where('type', Product::AUDIO_BOOK);
    }

    public function scopePodcast($q)
    {
        return $q->where('type', Product::PODCAST);
    }

    public function scopeMagazine($q)
    {
        return $q->where('type', Product::MAGAZINE);
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function order()
    {
        return $this->belongsTo(Order::class);
    }

    public function product()
    {
        return $this->belongsTo(Product::class);
    }

    public function translate()
    {
        return $this->belongsTo(ProductLanguage::class, 'product_language_id');
    }

    public function getLocaleProductAttribute()
    {
//        if (!$this->relationLoaded('product.translates.prices') || $this->relationLoaded('product.translates.collaborators') || $this->relationLoaded('product.translates.files'))
//            $this->load(['product.translates' => function ($q) {
//                $q->with(['prices.currency', 'collaborators', 'files' => function ($q) {
//                    $q->where('type', Product::MAIN_FILE);
//                }]);
//            }]);

        $this->load(['product', 'translate' => function ($q) {
            $q->with(['prices.currency', 'collaborators', 'files' => function ($q) {
                $q->where('type', Product::MAIN_FILE);
            }]);
        }]);

        return $this;
    }
}
