<?php

namespace App\Models;

use App\Contracts\TranslateModel;
use App\Helper\Enum;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Storage;

class ProductFile extends Model
{
    use HasFactory;

    protected $guarded = ['id'];

    protected $appends = ['url'];

    public function getUrlAttribute()
    {
        if ($this->type === Product::DEMO_FILE)
            return Storage::disk('demo')->url($this->path);
        else if ($this->type === Product::COVER_FILE)
            return Storage::url($this->path);

        return Storage::disk('product')->url($this->path);
    }

    public function product()
    {
        return $this->belongsTo(Product::class);
    }

    public function translate()
    {
        return $this->belongsTo(Language::class, 'language_locale');
    }

    public function productLanguage()
    {
        return $this->belongsTo(ProductLanguage::class);
    }

    public function publisher()
    {
        return $this->belongsTo(User::class, 'publisher_id')->where('role', Enum::PUBLISHER);
    }
}
