<?php

namespace App\Models;

use Cviebrock\EloquentSluggable\Sluggable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Storage;

class ProductLanguage extends Model
{
    use HasFactory, Sluggable,SoftDeletes;

    protected $guarded = ['id'];

    protected $casts = [
        'published_at' => 'datetime'
    ];

    protected $appends = ['cover_url'];

    public function sluggable(): array
    {
        return [
            'slug' => [
                'source' => 'title'
            ]
        ];
    }

    public function getCoverUrlAttribute()
    {
        return Storage::url($this->cover);
    }

    public function product()
    {
        return $this->belongsTo(Product::class);
    }

    public function collection(): BelongsTo
    {
        return $this->belongsTo(Collection::class);
    }

    public function collaborators()
    {
        return $this->belongsToMany(Collaborator::class, 'product_collaborators');
    }

    public function prices()
    {
        return $this->hasMany(ProductPrice::class);
    }

    public function files()
    {
        return $this->hasMany(ProductFile::class);
    }

    public function review()
    {
        return $this->hasOne(ProductReview::class);
    }

    public function highlights()
    {
        return $this->hasMany(Highlight::class);
    }

    public function notes()
    {
        return $this->hasMany(Note::class);
    }
}
