<?php

namespace App\Models;

use App\Contracts\TranslateModel;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Str;

class Setting extends TranslateModel
{
    use HasFactory;

    const ADDRESS = 'ADDRESS';
    const MOBILE = 'MOBILE';
    const PHONE = 'PHONE';
    const WORK_HOUR = 'WORK_HOUR';
    const CREDIT_CARD_NUMBER = 'CREDIT_CARD_NUMBER';
    const CREDIT_CARD_OWNER = 'CREDIT_CARD_OWNER';
    const ABOUT_US_DESCRIPTION = 'ABOUT_US_DESCRIPTION';
    const GUIDE_DESCRIPTION = 'GUIDE_DESCRIPTION';
    const WELCOME_MESSAGE = 'WELCOME_MESSAGE';
    const SUPPORT_TIME = 'SUPPORT_TIME';
    const PUBLISHER_PROFIT = 'PUBLISHER_PROFIT';
    const MARKETER_PROFIT = 'MARKETER_PROFIT';
    const SITE_PROFIT = 'SITE_PROFIT';
    const TWITTER = 'TWITTER';
    const INSTAGRAM = 'INSTAGRAM';
    const YOUTUBE = 'YOUTUBE';
    const WHATSAPP = 'WHATSAPP';
    const TELEGRAM = 'TELEGRAM';
    const FOOTER_TITLE = 'FOOTER_TITLE';
    const FOOTER_DESCRIPTION = 'FOOTER_DESCRIPTION';

    protected $guarded = ['id'];

    public function scopeValueOf($q, string|array $keys)
    {
        if (is_array($keys)) {
            return $q->whereIn('key', $keys);
        }

        return $q->where('key', $keys);
    }

    public function scopeValueOfCombined($q, string|array $keys)
    {
        $settings = $q->valueOf($keys)->get();

        $settingsArr = [];
        foreach ($settings as $setting) {
            $settingsArr[Str::lower($setting->key)] = $setting->value ?? $setting?->translate?->value;
        }

        return $settingsArr;
    }
}
