<?php

namespace App\Observers;

use App\Mail\ContactUsMail;
use App\Models\ContactUs;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Storage;

class ContactUsObserver
{
    /**
     * Handle the ContactUs "created" event.
     *
     * @param ContactUs $contactUs
     * @return void
     */
    public function created(ContactUs $contactUs)
    {
        Mail::to($contactUs->email)->send(new ContactUsMail($contactUs));
    }

    /**
     * Handle the ContactUs "updated" event.
     *
     * @param ContactUs $contactUs
     * @return void
     */
    public function updated(ContactUs $contactUs)
    {
        //
    }

    /**
     * Handle the ContactUs "deleted" event.
     *
     * @param ContactUs $contactUs
     * @return void
     */
    public function deleted(ContactUs $contactUs)
    {
        if ($contactUs->file_path && Storage::exists($contactUs->file_path))
            Storage::delete($contactUs->file_path);
    }

    /**
     * Handle the ContactUs "restored" event.
     *
     * @param ContactUs $contactUs
     * @return void
     */
    public function restored(ContactUs $contactUs)
    {
        //
    }

    /**
     * Handle the ContactUs "force deleted" event.
     *
     * @param ContactUs $contactUs
     * @return void
     */
    public function forceDeleted(ContactUs $contactUs)
    {
    }
}
