<?php

namespace App\Providers;

use App\Models\Admin;
use App\Models\Permission;
use Illuminate\Foundation\Support\Providers\AuthServiceProvider as ServiceProvider;
use Illuminate\Support\Facades\Gate;
use Illuminate\Support\Facades\Schema;
use Laravel\Passport\Passport;

class AuthServiceProvider extends ServiceProvider
{
    /**
     * The policy mappings for the application.
     *
     * @var array<class-string, class-string>
     */
    protected $policies = [
        // 'App\Models\Model' => 'App\Policies\ModelPolicy',
    ];

    /**
     * Register any authentication / authorization services.
     *
     * @return void
     */
    public function boot()
    {
        $this->registerPolicies();
        $this->defineGates();

        Passport::routes();

        Passport::tokensExpireIn(now()->addDays(30));
        Passport::refreshTokensExpireIn(now()->addDays(60));
        Passport::personalAccessTokensExpireIn(now()->addMonths(6));

        Passport::tokensCan([
            'user-access' => 'User Access',
            'admin-access' => 'Admin Access',
        ]);
    }

    protected function defineGates()
    {
        if (!Schema::hasTable('permissions'))
            return;

        $permissions = Permission::query()->cursor();

        foreach ($permissions as $permission) {
            Gate::define($permission->key, function (Admin $admin) use ($permission) {
                return $admin->hasPermission($permission);
            });
        }
    }
}
