<?php

namespace App\Rules;

use App\Models\Imageable;
use Illuminate\Contracts\Validation\Rule;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class FileExistRule implements Rule
{
    private string $disk;
    private string $root;
    private string $attribute;

    /**
     * Create a new rule instance.
     *
     * @return void
     */
    public function __construct(string $root = 'documents', string $disk = 'public')
    {
        $this->disk = $disk;
        $this->root = $root;
    }

    /**
     * Determine if the validation rule passes.
     *
     * @param string $attribute
     * @param mixed $value
     * @return bool
     */
    public function passes($attribute, $value)
    {
        $this->attribute = $attribute;
        if (!is_array($value)) {
            if (!Str::startsWith($value, $this->root)) {
                return false;
            }
            return Storage::disk($this->disk)->exists($value) && Imageable::query()->whereNull('imageable_id')->whereNull('imageable_type')->where('path', $value)->where('expired_at', '>', now()->toDateTimeString())->first();
        }

        $itemsCount = count($value);
        $dbItemsCount = Imageable::query()->whereNull('imageable_id')->whereNull('imageable_type')->where('expired_at', '>', now()->toDateTimeString())->whereIn('path', $value)->count();

        if ($itemsCount !== $dbItemsCount)
            return false;

        foreach ($value as $path) {
            if (!Storage::disk($this->disk)->exists($path) || !Str::startsWith($path, $this->root))
                return false;
        }

        return true;
    }

    /**
     * Get the validation error message.
     *
     * @return string
     */
    public function message()
    {
        $attributeKey = "validation.attributes.{$this->attribute}";

        $attributeTitle = trans($attributeKey);

        $attributeTitle = $attributeTitle === $attributeKey ? $this->attribute : $attributeTitle;

        return trans('validation.file_exists', ['attribute' => $attributeTitle]);
    }
}
