<?php

namespace App\Rules;

use App\Models\Imageable;
use App\Models\ProductFile;
use Illuminate\Contracts\Validation\Rule;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class ProductFileExistsRule implements Rule
{
    private $publisher;
    private string $disk;
    private string $attribute;

    /**
     * Create a new rule instance.
     *
     * @return void
     */
    public function __construct($publisher, string $disk = 'public')
    {
        //
        $this->publisher = $publisher;
        $this->disk = $disk;
    }

    /**
     * Determine if the validation rule passes.
     *
     * @param string $attribute
     * @param mixed $value
     * @return bool
     */
    public function passes($attribute, $value)
    {
        $this->attribute = $attribute;
        if ($value && !is_array($value)) {
//            return Storage::disk($this->disk)->exists($value) && ProductFile::query()->whereNull('product_id')->whereNull('product_language_id')->where('publisher_id', $this->publisher->id)->where('path', $value)->where('expired_at', '>', now()->toDateTimeString())->first();
            return Storage::disk($this->disk)->exists($value) && ProductFile::query()->where('publisher_id', $this->publisher->id)->where('path', $value)->first();
        }
        return false;
    }

    /**
     * Get the validation error message.
     *
     * @return string
     */
    public function message()
    {
        $attributeKey = "validation.attributes.{$this->attribute}";

        $attributeTitle = trans($attributeKey);

        $attributeTitle = $attributeTitle === $attributeKey ? $this->attribute : $attributeTitle;

        return trans('validation.file_exists', ['attribute' => $attributeTitle]);
    }
}
