<?php

namespace App\Rules;

use App\Helper\Enum;
use App\Models\User;
use Illuminate\Contracts\Validation\Rule;

class UniqueMobileRule implements Rule
{
    private $countryCode;
    private string $role;

    /**
     * Create a new rule instance.
     *
     * @return void
     */
    public function __construct($countryCode, $role = Enum::USER)
    {
        $this->countryCode = $countryCode;
        $this->role = $role;
    }

    /**
     * Determine if the validation rule passes.
     *
     * @param string $attribute
     * @param mixed $value
     * @return bool
     */
    public function passes($attribute, $value)
    {
        return !User::query()->where('mobile', 'LIKE', $value)->where('country_code', $this->countryCode)->where('role', $this->role)->first();
    }

    /**
     * Get the validation error message.
     *
     * @return string
     */
    public function message()
    {
        return trans('validation.unique_mobile');
    }
}
