<?php

namespace App\Services\Admin;

use App\Models\Product;
use App\Models\ReadingReport;

class ReportService
{
    protected function relation()
    {
        return [
            'publisher' => fn($q) => $q->with('publisherProfile:id,user_id,publisher_name')->select(['id']),
            'translates' => fn($q) => $q->select(['id', 'product_id', 'title'])
        ];
    }

    public function getSaleReportOf($type = null, $startedAt = null, $endedAt = null)
    {
        $report = Product::query()->with($this->relation())->mostPurchased($type, $startedAt, $endedAt)->first();
        return $report ? [
            'id' => $report->id,
            'title' => $report?->translate?->title,
            'publisher' => $report->publisher ? [
                'id' => $report->publisher?->id,
                'name' => $report->publisher?->publisherProfile?->publisher_name
            ] : null
        ] : null;
    }

    public function getReadingReportOf($type = null, $startedAt = null, $endedAt = null)
    {
        return ReadingReport::query()->where('type', $type)->whereBetween('read_at', [$startedAt, $endedAt])->sum('read_time');
    }
}
