<?php

namespace App\Services\Auth;

use App\Exceptions\FailedResponseException;
use App\Facades\OTP;
use App\Facades\Token;
use App\Helper\FailedResponseCode;
use App\Models\User;
use App\Services\DeviceService;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;

class ForgetPasswordService
{
    private $data;
    private $user;

    public function setData($data): static
    {
        $this->data = is_object($data) ? $data : (object)$data;
        return $this;
    }

    public function userExists(): static
    {
        $this->user = User::where('email', $this->data->email)->where('role', Str::upper($this->data->user_type))->first();

        if (!$this->user)
            throw new FailedResponseException(trans('failed-messages.invalid_email'), FailedResponseCode::INVALID_EMAIL);

        return $this;
    }

    public function requestCode(): int|null
    {
        return OTPService::sendCode($this->data);
    }

    public function verifyCode(): array
    {
        if (!OTPService::verifyCode($this->data)) {
            throw new FailedResponseException(trans('failed-messages.otp_invalid'), FailedResponseCode::OTP_INVALID);
        }

        $token = Token::generate();

        Token::save("{$this->data->user_type}_{$this->data->email}", $token);

        return [
            'email' => $this->data->email,
            'user_type' => $this->data->user_type,
            'token' => $token
        ];
    }

    public function changePassword(): array|null
    {
        if (!Token::verify("{$this->data->user_type}_{$this->data->email}", $this->data->token)) {
            throw new FailedResponseException(trans('failed-messages.forget_token_invalid'), FailedResponseCode::FORGET_TOKEN_INVALID);
        }

        Token::forget("{$this->data->user_type}_{$this->data->email}");

        $status = $this->user->update([
            'password' => bcrypt($this->data->password)
        ]);

        if (!$status)
            throw new FailedResponseException(trans('failed-messages.change_password_failed'), FailedResponseCode::CHANGE_PASSWORD_FAILED);

        DB::table('oauth_access_tokens')
            ->where('user_id', $this->user->id)
            ->where('revoked', 0)
            ->where('scopes', 'LIKE', "%user-access%")
            ->update([
                'revoked' => true
            ]);

        $this->user->devices()->forceDelete();

        return null;
    }
}
