<?php

namespace App\Services\Auth;

use App\Facades\OTP;
use App\Mail\SendOtpMail;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Mail;
use Vonage\Client;
use Vonage\Client\Credentials\Basic;
use Vonage\SMS\Message\SMS;
use Kavenegar;

class OTPService
{
    public static function sendCode($data, $key = null): int|null
    {
        $data = is_object($data) ? $data : (object)$data;
        $userType = $data->user_type ?? null;

        $code = OTP::generate();

        if (($data->mobile ?? null) && ($data->country_code ?? null)) {
            $status = OTP::save($key ?? "{$userType}_{$data->mobile}", $code);
            static::sendSMS($data->mobile, $data->country_code, $userType, $code);
        } else {
            $status = OTP::save($key ?? "{$userType}_{$data->email}", $code);
            static::sendEmail($data->email, $userType, $code);
        }

        return $status ? $code : null;
    }

    public static function verifyCode($data): bool
    {
        $data = is_object($data) ? $data : (object)$data;
        $userType = $data->user_type;

        if ($data->mobile ?? null && $data->country_code ?? null) {

            $isVerified = OTP::verify("{$userType}_{$data->mobile}", $data->otp);

            if ($isVerified) {
                OTP::forget("{$userType}_{$data->mobile}");
            }

            return $isVerified;
        }

        $isVerified = OTP::verify("{$userType}_{$data->email}", $data->otp);

        if ($isVerified) {
            OTP::forget("{$userType}_{$data->email}");
        }

        return $isVerified;
    }

    protected static function sendSMS($mobile, $countryCode, $userType, $code)
    {
        //TODO: send OTP SMS
//      $basic  = new Basic(env('NEXMO_KEY'), env('NEXMO_SECRET'));
//      $client = new Client($basic);
//      $response = $client->sms()->send(
//          new SMS($countryCode.$mobile, env('NEXMO_SMS_FROM'), "Your otp is : $code")
//      );

        $message = Kavenegar::VerifyLookup($countryCode.$mobile, $code, null, null, 'verify', $type = null);
//      $message = $response->current();
//      if ($message->getStatus() == 0) {
//          echo "The message was sent successfully\n";
//      } else {
//          echo "The message failed with status: " . $message->getStatus() . "\n";
//      }

    }

    protected static function sendEmail($email, $userType, $code)
    {
        Mail::to($email)->send(new SendOtpMail($code));
    }
}
