<?php

namespace App\Services;

use App\Models\Discount;
use App\Models\ProductPrice;

class DiscountService
{
    public static function getDiscount($code, $currency = null): Discount|null
    {
        return Discount::query()->with(['prices' => fn($q) => $currency ? $q->where('currency_code', $currency)->limit(1) : $q])->where('code', $code)->where(function ($q) {
            $q->whereRaw('used_count < max_usage')->orWhere('max_usage', null);
        })->where('started_at', '<', now())->where('ended_at', '>', now())->first();
    }

    public static function calculateDiscount(ProductPrice $price, Discount|null $discount = null,)
    {
        $priceValue = $price->price;
        $discountPercent = $price->discount_percent ?? 0;

        if ($discountPercent > 0 && now() > $price->discount_started_at && now() < $price->discount_ended_at) {
            return [
                'price' => ($priceValue * $discountPercent) / 100,
                'percent' => $discountPercent
            ];
        }

        if ($discount && now() > $discount->started_at && now() < $discount->ended_at) {
            return [
                'price' => ($priceValue * ($discount->prices->first()->percent ?? 0)) / 100,
                'percent' => $discount->prices->first()->percent
            ];
        }

        return [
            'price' => 0,
            'percent' => 0
        ];
    }
}
