<?php

namespace App\Services\Marketer\Auth;

use App\Contracts\UsernameRegister;
use App\Helper\Enum;
use App\Helper\Image;
use App\Helper\ReferralGenerator;
use App\Http\Resources\Marketer\MarketerResource;
use App\Models\Setting;
use App\Models\User;
use App\Notifications\MarketerRegisteredNotification;
use App\Services\DeviceService;
use Cviebrock\EloquentSluggable\Services\SlugService;
use Illuminate\Support\Str;

class RegisterService extends UsernameRegister
{
    public function register(): array
    {
        $username = Str::before($this->data->email, '@');
        $username = SlugService::createSlug(User::class, 'username', $username);
        $password = Str::random(8);
//      $password = '12345678';

        $user = User::create([
            'first_name' => $this->data->first_name,
            'last_name' => $this->data->last_name,
            'role' => Enum::MARKETER,
            'national_code' => $this->data->national_code,
            'gender' => $this->data->gender,
            'country_code' => $this->data->country_code,
            'mobile' => $this->data->mobile,
            'mobile_verified_at' => now(),
            'email' => $this->data->email,
            'username' => $username,
            'password' => bcrypt($password),
            'referral_code' => ReferralGenerator::generate()
        ]);

        if (isset($this->data->referral))
            ReferralGenerator::saveInvite($this->referralOwner, $user);

        if (isset($this->data->documents))
            Image::markAsPermanent($user, $this->data->documents);

        $this->sendNotification($user, $username, $password);

        DeviceService::connect($user);

        return [
            'user' => new MarketerResource($user),
            'token' => $user->createToken('marketer auth token', ['user-access'])->accessToken
        ];
    }

    protected function sendNotification($notifiable, string $username, string $password)
    {
        $notifiable->notify(new MarketerRegisteredNotification($username, $password));
    }
}
