<?php

namespace App\Services\Product;

use App\Helper\Enum;
use App\Models\Product;
use App\Models\ProductLanguage;
use App\Models\User;

class ProductViewService
{
    public static function alreadyPurchased(Product $product, User $user = null, ProductLanguage $productLanguage = null, $productType = null): array|null
    {
        $translate = $productLanguage ?: $product->translate;
        if ($translate->purchase_type === Product::FREE)
            return null;

        if (!$user || !$user->tokenCan('user-access') || $user->role !== Enum::USER)
            return null;

        $variantsPurchased = $user->alreadyPurchased($product, $translate, $productType)->get();

        $electronicBook = $variantsPurchased->where('type', Product::ELECTRONIC_BOOK)->first();
        $audioBook = $variantsPurchased->where('type', Product::AUDIO_BOOK)->first();
        $magazine = $variantsPurchased->where('type', Product::MAGAZINE)->first();
        $podcast = $variantsPurchased->where('type', Product::PODCAST)->first();


        $data = [];

        if ($electronicBook) {
            $data['electronic_book'] = true;
        }
        if ($audioBook) {
            $data['audio_book'] = true;
        }
        if ($magazine) {
            $data['magazine'] = true;
        }
        if ($podcast) {
            $data['podcast'] = true;
        }


        return $variantsPurchased->count() ? $data : null;
    }

    public static function inCart(Product $product, User $user = null, ProductLanguage $productLanguage = null, $productType = null): array|null
    {
        $translate = $productLanguage ?: $product->translate;

        if ($translate->purchase_type === Product::FREE)
            return null;

        if (!$user || !$user->tokenCan('user-access') || $user->role !== Enum::USER)
            return null;

        $variantsInCart = $user->inCart($product, $translate, $productType)->get();

        $electronicBook = $variantsInCart->where('type', Product::ELECTRONIC_BOOK)->first();
        $audioBook = $variantsInCart->where('type', Product::AUDIO_BOOK)->first();
        $magazine = $variantsInCart->where('type', Product::MAGAZINE)->first();
        $podcast = $variantsInCart->where('type', Product::PODCAST)->first();

        $data = [
            'electronic_book' => false,
            'audio_book' => false,
            'magazine' => false,
            'podcast' => false,
        ];

        if ($electronicBook) {
            $data['electronic_book'] = true;
        }
        if ($audioBook) {
            $data['audio_book'] = true;
        }
        if ($magazine) {
            $data['magazine'] = true;
        }
        if ($podcast) {
            $data['podcast'] = true;
        }

        return $data;
    }

    protected function purchasedProductItems()
    {
        if ($this->translate->purchase_type === Product::FREE)
            return null;

        if (!$this->user || !$this->user->tokenCan('user-access') || $this->user->role !== Enum::USER)
            return null;

        $variantsPurchased = $this->user->alreadyPurchased($this->resource)->get();

        $electronicBook = $variantsPurchased->where('type', Product::ELECTRONIC_BOOK)->first();
        $audioBook = $variantsPurchased->where('type', Product::AUDIO_BOOK)->first();
        $magazine = $variantsPurchased->where('type', Product::MAGAZINE)->first();
        $podcast = $variantsPurchased->where('type', Product::PODCAST)->first();

        return $variantsPurchased->count() ? [
            'electronic_book' => $this->when((bool)$electronicBook, (bool)$electronicBook),
            'audio_book' => $this->when((bool)$audioBook, (bool)$audioBook),
            'magazine' => $this->when((bool)$magazine, (bool)$magazine),
            'podcast' => $this->when((bool)$podcast, (bool)$podcast)
        ] : null;
    }
}
