<?php

namespace App\Services\Publisher;

use App\Exceptions\FailedResponseException;
use App\Helper\FailedResponseCode;
use App\Models\Product;
use App\Models\ProductFile;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;
use wapmorgan\Mp3Info\Mp3Info;


class ProductFileService
{
    protected string $productType;
    protected string $productFileType;
    protected ?ProductFile $productFile = null;


    public function setProductType(string $productType)
    {
        $this->productType = $productType;
        return $this;
    }

    public function setProductFileType(string $productFileType)
    {
        $this->productFileType = $productFileType;
        return $this;
    }

    public function setProductFile(ProductFile $productFile)
    {
        $this->productFile = $productFile;
        return $this;
    }

    public function storeAndUpdate(UploadedFile $file)
    {
        $root = Str::lower($this->productType);
        $year = now()->year;
        $folder = Str::lower($this->productFileType);
        if ($this->productFileType === Product::DEMO_FILE || $this->productFileType === Product::COVER_FILE) {
            $result = Storage::putFile("/$root/$year", $file);
        } else {
            $result = Storage::disk('product')->putFile("/$root/$year", $file);
        }

        if (!$result) {
            return failedResponse(trans('failed-messages.file_upload_storage_failed'), FailedResponseCode::FILE_UPLOAD_FAILED);
        }

        if ($this->productType === Product::ELECTRONIC_BOOK && $file->extension() === 'mp3') {
            $productType = Product::AUDIO_BOOK;
        } else {
            $productType = $this->productType;
        }

        $audio = null;

        if ($file->extension() === 'mp3') {
//                return storage_path($this->productFileType === Product::DEMO_FILE ? 'app/public/'.$result : 'app/products/'.$result);
            $audio = new Mp3Info(storage_path($this->productFileType === Product::DEMO_FILE ? 'app/public/' . $result : 'app/products/' . $result));
        }


        if ($this->productFile) {
            $result = $this->productFile->update([
                'path' => $result,
                'type' => $this->productFileType,
                'product_type' => $productType,
                'extension' => $file->extension(),
                'mime_type' => $file->getClientMimeType(),
                'size' => (+$file->getSize()) / 1048576,
                'duration' => $audio?->duration ? (int)$audio?->duration : null
            ]);
        } else {
            $result = !!$this->productFile = auth()->user()->productFiles()->create([
                'path' => $result,
                'type' => $this->productFileType,
                'product_type' => $productType,
                'extension' => $file->extension(),
                'mime_type' => $file->getClientMimeType(),
                'expired_at' => now()->addHours(3),
                'size' => (+$file->getSize()) / 1048576,
                'duration' => $audio?->duration ? (int)$audio?->duration : null
            ]);
        }


        return $result ? [
            'id' => $this->productFile->id,
            'type' => Str::lower($this->productFile->type),
            'product_type' => Str::lower($productType),
            'path' => $this->productFile->path,
            'url' => $this->productFile->url,
            'duration' => $this->productFile->duration,
            'size' => $this->productFile->size,
        ] : null;
    }
}
