<?php

namespace App\Services\User;

use App\Exceptions\FailedResponseException;
use App\Helper\FailedResponseCode;
use App\Models\ProductLanguage;
use App\Services\DiscountService;

class OrderService
{
    public function getPrices($orderProducts, $currency, $discountCode = null)
    {
        $productPrices = [];

        $discount = $discountCode ? DiscountService::getDiscount($discountCode, $currency) : null;

        foreach ($orderProducts as $orderProduct) {
            $productPrice = $orderProduct->locale_product->translate?->prices->where('currency_code', $currency)->first();


            $price = $totalDiscountPrice = $productPrice->price;
            $discountPrice = DiscountService::calculateDiscount($productPrice, $discount);
            $discountPercent = $discountPrice['percent'];

            if ($discountPrice > 0) {
                $totalDiscountPrice = $price - $discountPrice['price'];
            }

            $productPrices[$orderProduct->id] = [
                'price' => number_format($productPrice->price, $productPrice->currency->floating_point ? 2 : 0, '.', ''),
                'discount_percent' => $discountPercent,
                'discount_price' => number_format($discountPrice['price'], $productPrice->currency->floating_point ? 2 : 0, '.', ''),
                'total_price' => number_format($totalDiscountPrice, $productPrice->currency->floating_point ? 2 : 0, '.', ''),
            ];
        }

        return $productPrices;
    }

    public function updateOrderProductPrices($orderProducts, $prices)
    {
        foreach ($prices as $id => $price) {
            $orderProduct = $orderProducts->where('id', $id)->first();
            $orderProduct->update([
                'price' => $price['price'],
                'discount' => $price['discount_percent'],
                'total_price' => $price['total_price']
            ]);
        }
    }
}
