<?php

namespace App\Services\User\Profile;

use App\Models\User;
use Carbon\Carbon;
use Illuminate\Support\Arr;

class ReadingReportService
{
    public static function getDailyReport(User $user)
    {
        $user->load(['readingReports' => fn($q) => $q->orderBy('read_at', 'desc')->limit(30)]);
        $days = [];
        foreach ($user->readingReports as $report) {
            $days[$report->read_at] = [
                'title' => $days[$report->read_at]['title'] ?? Carbon::parse($report->read_at)->format("M d"),
                'value' => ($days[$report->read_at]['value'] ?? 0) + $report->read_time
            ];
        }
        return array_reverse(array_values($days));
    }

    public static function getWeeklyReport(User $user)
    {
        $readingReport = $user->readingReports()->orderBy('read_at', 'desc')->first();
        if (!$readingReport)
            return [];

        $weekLimit = 10;
        $day = Carbon::parse($readingReport->read_at);
        $day->subWeeks($weekLimit - 1);

        $weeks = [];
        $sawNext = false;
        for ($i = 0; $i < $weekLimit; $i++) {
            $startOfWeek = $day->copy()->startOfWeek();
            $endOfWeek = $day->copy()->endOfWeek();


            $sum = $user->readingReports()->whereBetween('read_at', [
                $startOfWeek->toDateString(),
                $endOfWeek->toDateString()
            ])->sum('read_time');

            if (!$sum && !$sawNext) {
                $day->addWeek();
                continue;
            }
            $sawNext = true;

            $startOfWeekFormat = $startOfWeek->format("M d");
            $endOfWeekFormatFormat = $endOfWeek->format("M d");

            $weeks[] = [
                'title' => "$startOfWeekFormat - $endOfWeekFormatFormat",
                'value' => $sum
            ];

            $day->addWeek();
        }

        return $weeks;
    }

    public static function getMonthlyReport(User $user)
    {
        $readingReport = $user->readingReports()->orderBy('read_at', 'desc')->first();
        if (!$readingReport)
            return [];

        $monthLimit = 10;
        $day = Carbon::parse($readingReport->read_at);
        $day->subMonths($monthLimit - 1);

        $months = [];
        $sawNext = false;
        for ($i = 0; $i < $monthLimit; $i++) {
            $startOfMonth = $day->copy()->startOfMonth();
            $endOfMonth = $day->copy()->endOfMonth();


            $sum = $user->readingReports()->whereBetween('read_at', [
                $startOfMonth->toDateString(),
                $endOfMonth->toDateString()
            ])->sum('read_time');

            if (!$sum && !$sawNext) {
                $day->addMonth();
                continue;
            }
            $sawNext = true;

            $startOfMonthFormat = $startOfMonth->format("M d");
            $endOfMonthFormatFormat = $endOfMonth->format("M d");

            $months[] = [
                'title' => "$startOfMonthFormat - $endOfMonthFormatFormat",
                'value' => $sum
            ];

            $day->addMonth();
        }

        return $months;
    }

    public static function getTotalAverageReport(User $user)
    {
        $user->loadSum('readingReports as report_sum', 'read_time')
            ->loadCount('readingReports as report_count');

        return [
            'total_report_time' => $user->report_sum,
            'total_report_count' => $user->report_count,
            'average' => $user->report_count ? $user->report_sum / $user->report_count : 0,
            'average_format' => convertSecondToDHMS($user->report_count ? $user->report_sum / $user->report_count : 0)
        ];
    }
}
