<?php

namespace App\Traits;

use App\Helper\Enum;
use App\Helper\FailedResponseCode;
use App\Models\Imageable;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

trait FileUploaderTrait
{
    public function store(Request $request, $owner = null): JsonResponse
    {
        $data = $request->validate($this->rules());

        $result = Storage::putFile($this->path(), $data[$this->fieldName()]);

        if (!$result) {
            return failedResponse(trans('failed-messages.file_upload_storage_failed'), FailedResponseCode::FILE_UPLOAD_FAILED);
        }
        $id = auth('admin')->user()?->tokenCan('admin-access') ? User::query()->where(fn($q) => $q->where('role', Enum::PUBLISHER)->orWhere('role', Enum::MARKETER))->find($owner)?->id : auth()->id();

        if ($res = $this->beforeStore($result)) {
            return $res;
        }

        $imageable = Imageable::create([
            'imageable_id' => $id ?? null,
            'imageable_type' => $id ? User::class : null,
            'path' => $result,
            'expired_at' => $id ? null : $this->expire()
        ]);

        if ($res = $this->afterStore($imageable)) {
            return $res;
        }

        return $imageable
            ? successResponse([
                'id' => $imageable->id,
                'path' => $imageable->path,
                'url' => $imageable->url
            ])
            : failedResponse(trans('failed-messages.file_upload_storage_failed'), FailedResponseCode::FILE_STORE_FAILED);
    }

    protected function afterStore(Imageable $imageable): JsonResponse|null
    {
        return null;
    }

    protected function beforeStore(string $path): JsonResponse|null
    {
        return null;
    }

    protected function rules(): array
    {
        return [
            'file' => ['required', 'image']
        ];
    }

    protected function fieldName(): string
    {
        return 'file';
    }

    protected function path(): string
    {
        return '/';
    }

    protected function expire(): Carbon
    {
        return now()->addHour();
    }
}
