<?php

namespace App\Traits;

use App\Exceptions\FailedResponseException;
use App\Models\Transaction;
use App\Models\Wallet;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

trait HasWallet
{
    public function receiptDeposit(Wallet $wallet, $amount, UploadedFile $receipt)
    {
        if (!$this->canUploadReceipt($wallet))
            throw new FailedResponseException();

        $path = $this->storeReceipt($receipt);
        if (!$path)
            throw new FailedResponseException();

        $transaction = $this->makeTransaction([
            'uuid' => Str::uuid()->toString(),
            'transactionable_id' => $wallet->id,
            'transactionable_type' => Wallet::class,
            'user_id' => $this->id,
            'currency_code' => $wallet->currency_code,
            'amount' => $amount,
            'receipt_path' => $path,
            'wallet_action' => Transaction::ACTION_DEPOSIT,
            'status' => Transaction::CHECKING
        ]);

        return $transaction;
    }

    protected function storeReceipt(UploadedFile $receipt): false|string
    {
        $year = now()->year;
        return Storage::disk('receipt')->putFile("/$year", $receipt);
    }

    protected function canUploadReceipt(Wallet $wallet): bool
    {
        if (!$wallet->relationLoaded('currency'))
            $wallet->load('currency');

        return !!$wallet?->currency?->receipt;
    }

    protected function makeTransaction($data): Transaction
    {
        return $this->transactions()->create($data);
    }

    public function requestDeposit(Wallet $wallet, $amount)
    {
        $wallet->load('currency');


    }

    public function deposit(Wallet $wallet, $amount)
    {

    }
}
