<?php

namespace App\Traits;

use App\Helper\Enum;
use App\Helper\FailedResponseCode;
use App\Http\Requests\Marketer\Auth\LoginRequest;
use App\Models\Marketer;
use App\Models\User;
use App\Services\DeviceService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

trait UsernameLoginTrait
{
    public function login(Request $request)
    {
        $data = (object)$request->validate($this->rules());

        $user = User::query()->where('username', $data->username)->where('role', $this->role())->first();

        if (!$user || !Hash::check($data->password, $user->password))
            return failedResponse(trans('failed-messages.invalid_credentials_2'), FailedResponseCode::INVALID_CREDENTIALS);

        DeviceService::connect($user);

        return successResponse([
            'user' => $this->resource($user),
            'token' => $user->createToken('user auth token', ['user-access'])->accessToken
        ]);
    }

    protected function rules(): array
    {
        return [
            'username' => ['required', 'string'],
            'password' => ['required', 'string']
        ];
    }

    protected function role()
    {
        return Enum::MARKETER;
    }

    protected function resource($client)
    {
        return $client;
    }
}
